@@ -52,6 +52,16 @@ function ShowMentionName() {
     return false;
 }
 
+function ShowNotLoadedEmoji() {
+    ShowToast("This custom emoji is not included, change data exporting settings to download.");
+    return false;
+}
+
+function ShowNotAvailableEmoji() {
+    ShowToast("This custom emoji is not available.");
+    return false;
+}
+
 function ShowSpoiler(target) {
     if (target.classList.contains("hidden")) {
         target.classList.toggle("hidden");
