@@ -21,8 +21,9 @@ public:
 		uint64 hash = 0;
 
 		bool incomplete = false;
+		int apiId = 0;
 		TimeId activeTime = 0;
-		QString name, active, info, ip;
+		QString name, active, info, ip, location, system, platform;
 	};
 	using List = std::vector<Entry>;
 
@@ -40,6 +41,17 @@ public:
 	[[nodiscard]] int total() const;
 	[[nodiscard]] rpl::producer<int> totalChanges() const;
 
+	void updateTTL(int days);
+	[[nodiscard]] rpl::producer<int> ttlDays() const;
+
+	void toggleCallsDisabledHere(bool disabled) {
+		toggleCallsDisabled(0, disabled);
+	}
+	void toggleCallsDisabled(uint64 hash, bool disabled);
+	[[nodiscard]] bool callsDisabledHere() const;
+	[[nodiscard]] rpl::producer<bool> callsDisabledHereValue() const;
+	[[nodiscard]] rpl::producer<bool> callsDisabledHereChanges() const;
+
 private:
 	MTP::Sender _api;
 	mtpRequestId _requestId = 0;
@@ -47,7 +59,14 @@ private:
 	List _list;
 	rpl::event_stream<> _listChanges;
 
+	mtpRequestId _ttlRequestId = 0;
+	rpl::variable<int> _ttlDays = 0;
+
+	base::flat_map<uint64, mtpRequestId> _toggleCallsDisabledRequests;
+	rpl::variable<bool> _callsDisabledHere;
+
 	crl::time _lastReceived = 0;
+	rpl::lifetime _lifetime;
 
 };
 
