@@ -31,7 +31,11 @@ void ConfirmPhone::resolve(
 	}
 	_sendRequestId = _api.request(MTPaccount_SendConfirmPhoneCode(
 		MTP_string(hash),
-		MTP_codeSettings(MTP_flags(0), MTP_vector<MTPbytes>())
+		MTP_codeSettings(
+			MTP_flags(0),
+			MTPVector<MTPbytes>(),
+			MTPstring(),
+			MTPBool())
 	)).done([=](const MTPauth_SentCode &result) {
 		_sendRequestId = 0;
 
@@ -54,6 +58,8 @@ void ConfirmPhone::resolve(
 				return bad("FlashCall");
 			}, [&](const MTPDauth_sentCodeTypeMissedCall &) {
 				return bad("MissedCall");
+			}, [&](const MTPDauth_sentCodeTypeFirebaseSms &) {
+				return bad("FirebaseSms");
 			}, [&](const MTPDauth_sentCodeTypeEmailCode &) {
 				return bad("EmailCode");
 			}, [&](const MTPDauth_sentCodeTypeSetUpEmailRequired &) {
@@ -89,7 +95,7 @@ void ConfirmPhone::resolve(
 				_api.request(MTPauth_ResendCode(
 					MTP_string(phone),
 					MTP_string(phoneHash)
-				)).done([=](const MTPauth_SentCode &result) {
+				)).done([=] {
 					if (boxWeak) {
 						boxWeak->callDone();
 					}
@@ -135,6 +141,9 @@ void ConfirmPhone::resolve(
 			}, box->lifetime());
 
 			controller->show(std::move(box), Ui::LayerOption::CloseOther);
+		}, [](const MTPDauth_sentCodeSuccess &) {
+			LOG(("API Error: Unexpected auth.sentCodeSuccess "
+				"(Api::ConfirmPhone)."));
 		});
 	}).fail([=](const MTP::Error &error) {
 		_sendRequestId = 0;
