@@ -25,6 +25,7 @@ class SessionController;
 
 namespace Ui {
 class Checkbox;
+class ChatStyle;
 } // namespace Ui
 
 class BackgroundPreviewBox
@@ -56,11 +57,11 @@ private:
 	void radialAnimationCallback(crl::time now);
 	QRect radialRect() const;
 
+	void generateBackground();
 	void checkLoadedDocument();
-	bool setScaledFromThumb();
+	void setScaledFromThumb();
 	void setScaledFromImage(QImage &&image, QImage &&blurred);
-	void updateServiceBg(std::optional<QColor> background);
-	std::optional<QColor> patternBackgroundColor() const;
+	void updateServiceBg(const std::vector<QColor> &bg);
 	void paintImage(Painter &p);
 	void paintRadial(Painter &p);
 	void paintTexts(Painter &p, crl::time ms);
@@ -71,12 +72,13 @@ private:
 	void checkBlurAnimationStart();
 
 	const not_null<Window::SessionController*> _controller;
+	std::unique_ptr<Ui::ChatStyle> _chatStyle;
 	AdminLog::OwnedItem _text1;
 	AdminLog::OwnedItem _text2;
 	Data::WallPaper _paper;
 	std::shared_ptr<Data::DocumentMedia> _media;
 	QImage _full;
-	QPixmap _scaled, _blurred, _fadeOutThumbnail;
+	QPixmap _generated, _scaled, _blurred, _fadeOutThumbnail;
 	Ui::Animations::Simple _fadeIn;
 	Ui::RadialAnimation _radial;
 	base::binary_guard _generating;
