@@ -49,7 +49,8 @@ public:
 
 	QString generateName() override;
 	QString generateShortName() override;
-	PaintRoundImageCallback generatePaintUserpicCallback() override;
+	PaintRoundImageCallback generatePaintUserpicCallback(
+		bool forceRound) override;
 
 private:
 	[[nodiscard]] Flag flag() const;
@@ -62,7 +63,8 @@ public:
 
 	QString generateName() override;
 	QString generateShortName() override;
-	PaintRoundImageCallback generatePaintUserpicCallback() override;
+	PaintRoundImageCallback generatePaintUserpicCallback(
+		bool forceRound) override;
 
 };
 
@@ -124,7 +126,8 @@ QString TypeRow::generateShortName() {
 	return generateName();
 }
 
-PaintRoundImageCallback TypeRow::generatePaintUserpicCallback() {
+PaintRoundImageCallback TypeRow::generatePaintUserpicCallback(
+		bool forceRound) {
 	const auto flag = this->flag();
 	return [=](QPainter &p, int x, int y, int outerWidth, int size) {
 		PaintFilterChatsTypeIcon(p, flag, x, y, outerWidth, size);
@@ -153,11 +156,15 @@ QString ExceptionRow::generateShortName() {
 	return generateName();
 }
 
-PaintRoundImageCallback ExceptionRow::generatePaintUserpicCallback() {
+PaintRoundImageCallback ExceptionRow::generatePaintUserpicCallback(
+		bool forceRound) {
 	const auto peer = this->peer();
 	const auto saved = peer->isSelf();
 	const auto replies = peer->isRepliesChat();
-	auto userpic = saved ? nullptr : ensureUserpicView();
+	auto userpic = saved ? Ui::PeerUserpicView() : ensureUserpicView();
+	if (forceRound && peer->isForum()) {
+		return ForceRoundUserpicCallback(peer);
+	}
 	return [=](Painter &p, int x, int y, int outerWidth, int size) mutable {
 		if (saved) {
 			Ui::EmptyUserpic::PaintSavedMessages(p, x, y, outerWidth, size);
@@ -248,7 +255,7 @@ void PaintFilterChatsTypeIcon(
 		int y,
 		int outerWidth,
 		int size) {
-	const auto &color = [&]() -> const style::color& {
+	const auto &color1 = [&]() -> const style::color& {
 		switch (flag) {
 		case Flag::Contacts: return st::historyPeer4UserpicBg;
 		case Flag::NonContacts: return st::historyPeer7UserpicBg;
@@ -261,6 +268,19 @@ void PaintFilterChatsTypeIcon(
 		}
 		Unexpected("Flag in color paintFlagIcon.");
 	}();
+	const auto &color2 = [&]() -> const style::color& {
+		switch (flag) {
+		case Flag::Contacts: return st::historyPeer4UserpicBg2;
+		case Flag::NonContacts: return st::historyPeer7UserpicBg2;
+		case Flag::Groups: return st::historyPeer2UserpicBg2;
+		case Flag::Channels: return st::historyPeer1UserpicBg2;
+		case Flag::Bots: return st::historyPeer6UserpicBg2;
+		case Flag::NoMuted: return st::historyPeer6UserpicBg2;
+		case Flag::NoArchived: return st::historyPeer4UserpicBg2;
+		case Flag::NoRead: return st::historyPeer7UserpicBg2;
+		}
+		Unexpected("Flag in color paintFlagIcon.");
+	}();
 	const auto &icon = [&]() -> const style::icon& {
 		switch (flag) {
 		case Flag::Contacts: return st::windowFilterTypeContacts;
@@ -276,7 +296,9 @@ void PaintFilterChatsTypeIcon(
 	}();
 	const auto rect = style::rtlrect(x, y, size, size, outerWidth);
 	auto hq = PainterHighQualityEnabler(p);
-	p.setBrush(color->b);
+	auto bg = QLinearGradient(x, y, x, y + size);
+	bg.setStops({ { 0., color1->c }, { 1., color2->c } });
+	p.setBrush(bg);
 	p.setPen(Qt::NoPen);
 	p.drawEllipse(rect);
 	icon.paintInCenter(p, rect);
@@ -463,6 +485,6 @@ auto EditFilterChatsListController::createRow(not_null<History*> history)
 void EditFilterChatsListController::updateTitle() {
 	const auto count = delegate()->peerListSelectedRowsCount()
 		- selectedTypesCount();
-	const auto additional = qsl("%1 / %2").arg(count).arg(_limit);
+	const auto additional = u"%1 / %2"_q.arg(count).arg(_limit);
 	delegate()->peerListSetAdditionalTitle(rpl::single(additional));
 }
