@@ -402,7 +402,9 @@ void PeerListsBox::addSelectItem(
 	addSelectItem(
 		peer->id.value,
 		peer->shortName(),
-		PaintUserpicCallback(peer, false),
+		(peer->isForum()
+			? ForceRoundUserpicCallback(peer)
+			: PaintUserpicCallback(peer, false)),
 		animated);
 }
 
@@ -412,7 +414,7 @@ void PeerListsBox::addSelectItem(
 	addSelectItem(
 		row->id(),
 		row->generateShortName(),
-		row->generatePaintUserpicCallback(),
+		row->generatePaintUserpicCallback(true),
 		animated);
 }
 
