@@ -7,49 +7,34 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 */
 #pragma once
 
-#include "boxes/abstract_box.h"
 #include "data/data_chat_participant_status.h"
 
 namespace Ui {
+class GenericBox;
 class RoundButton;
+class RpWidget;
 class VerticalLayout;
 } // namespace Ui
 
+template <typename Object>
+class object_ptr;
+
 namespace Window {
 class SessionController;
 class SessionNavigation;
 } // namespace Window
 
-class EditPeerPermissionsBox : public Ui::BoxContent {
-public:
-	EditPeerPermissionsBox(
-		QWidget*,
-		not_null<Window::SessionNavigation*> navigation,
-		not_null<PeerData*> peer);
-
-	struct Result {
-		ChatRestrictions rights;
-		int slowmodeSeconds = 0;
-	};
-
-	rpl::producer<Result> saveEvents() const;
-
-protected:
-	void prepare() override;
-
-private:
-	Fn<int()> addSlowmodeSlider(not_null<Ui::VerticalLayout*> container);
-	void addSlowmodeLabels(not_null<Ui::VerticalLayout*> container);
-	void addSuggestGigagroup(not_null<Ui::VerticalLayout*> container);
-	void addBannedButtons(not_null<Ui::VerticalLayout*> container);
-
-	const not_null<Window::SessionNavigation*> _navigation;
-	const not_null<PeerData*> _peer;
-	Ui::RoundButton *_save = nullptr;
-	Fn<Result()> _value;
-
+struct EditPeerPermissionsBoxResult final {
+	ChatRestrictions rights;
+	int slowmodeSeconds = 0;
 };
 
+void ShowEditPeerPermissionsBox(
+	not_null<Ui::GenericBox*> box,
+	not_null<Window::SessionNavigation*> navigation,
+	not_null<PeerData*> channelOrGroup,
+	Fn<void(EditPeerPermissionsBoxResult)> done);
+
 [[nodiscard]] Fn<void()> AboutGigagroupCallback(
 	not_null<ChannelData*> channel,
 	not_null<Window::SessionController*> controller);
@@ -68,26 +53,28 @@ struct AdminRightLabel {
 [[nodiscard]] std::vector<AdminRightLabel> AdminRightLabels(
 	Data::AdminRightsSetOptions options);
 
-template <typename Flags>
+template <typename Flags, typename Widget>
 struct EditFlagsControl {
-	object_ptr<Ui::RpWidget> widget;
+	object_ptr<Widget> widget;
 	Fn<Flags()> value;
 	rpl::producer<Flags> changes;
 };
 
-[[nodiscard]] EditFlagsControl<ChatRestrictions> CreateEditRestrictions(
+[[nodiscard]] auto CreateEditRestrictions(
 	QWidget *parent,
 	rpl::producer<QString> header,
 	ChatRestrictions restrictions,
 	std::map<ChatRestrictions, QString> disabledMessages,
-	Data::RestrictionsSetOptions options);
+	Data::RestrictionsSetOptions options)
+-> EditFlagsControl<ChatRestrictions, Ui::RpWidget>;
 
-[[nodiscard]] EditFlagsControl<ChatAdminRights> CreateEditAdminRights(
+[[nodiscard]] auto CreateEditAdminRights(
 	QWidget *parent,
 	rpl::producer<QString> header,
 	ChatAdminRights rights,
 	std::map<ChatAdminRights, QString> disabledMessages,
-	Data::AdminRightsSetOptions options);
+	Data::AdminRightsSetOptions options)
+-> EditFlagsControl<ChatAdminRights, Ui::RpWidget>;
 
 [[nodiscard]] ChatAdminRights DisabledByDefaultRestrictions(
 	not_null<PeerData*> peer);
