@@ -23,6 +23,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "data/data_chat_filters.h"
 #include "data/data_user.h"
 #include "data/data_channel.h"
+#include "data/data_forum.h"
 #include "data/data_session.h"
 #include "data/data_folder.h"
 #include "data/data_premium_limits.h"
@@ -800,6 +801,25 @@ void PinsLimitBox(
 		PinsCount(session->data().chatsList()));
 }
 
+void ForumPinsLimitBox(
+		not_null<Ui::GenericBox*> box,
+		not_null<Data::Forum*> forum) {
+	const auto current = forum->owner().pinnedChatsLimit(forum) * 1.;
+
+	auto text = tr::lng_forum_pin_limit(
+		lt_count,
+		rpl::single(current),
+		Ui::Text::RichLangValue);
+	SimpleLimitBox(
+		box,
+		&forum->session(),
+		false,
+		tr::lng_filter_pin_limit_title(),
+		std::move(text),
+		QString(),
+		{ current, current, current * 2, &st::premiumIconPins });
+}
+
 void CaptionLimitBox(
 		not_null<Ui::GenericBox*> box,
 		not_null<Main::Session*> session,
