@@ -114,6 +114,41 @@ rpl::producer<QString> FieldPlaceholder(
 
 } // namespace
 
+SendFilesLimits DefaultLimitsForPeer(not_null<PeerData*> peer) {
+	using Flag = SendFilesAllow;
+	using Restriction = ChatRestriction;
+	const auto allowByRestriction = [&](Restriction check, Flag allow) {
+		return Data::RestrictionError(peer, check) ? Flag() : allow;
+	};
+	return Flag()
+		| (peer->slowmodeApplied() ? Flag::OnlyOne : Flag())
+		| (Data::AllowEmojiWithoutPremium(peer)
+			? Flag::EmojiWithoutPremium
+			: Flag())
+		| allowByRestriction(Restriction::SendPhotos, Flag::Photos)
+		| allowByRestriction(Restriction::SendVideos, Flag::Videos)
+		| allowByRestriction(Restriction::SendMusic, Flag::Music)
+		| allowByRestriction(Restriction::SendFiles, Flag::Files)
+		| allowByRestriction(Restriction::SendStickers, Flag::Stickers)
+		| allowByRestriction(Restriction::SendGifs, Flag::Gifs)
+		| allowByRestriction(Restriction::SendOther, Flag::Texts);
+}
+
+SendFilesCheck DefaultCheckForPeer(
+		not_null<Window::SessionController*> controller,
+		not_null<PeerData*> peer) {
+	return [=](
+			const Ui::PreparedFile &file,
+			bool compress,
+			bool silent) {
+		const auto error = Data::FileRestrictionError(peer, file, compress);
+		if (error && !silent) {
+			controller->showToast({ *error });
+		}
+		return !error.has_value();
+	};
+}
+
 SendFilesBox::Block::Block(
 	not_null<QWidget*> parent,
 	not_null<std::vector<Ui::PreparedFile>*> items,
@@ -289,16 +324,17 @@ SendFilesBox::SendFilesBox(
 	not_null<Window::SessionController*> controller,
 	Ui::PreparedList &&list,
 	const TextWithTags &caption,
-	not_null<PeerData*> peer,
+	SendFilesLimits limits,
+	SendFilesCheck check,
 	Api::SendType sendType,
 	SendMenu::Type sendMenuType)
 : _controller(controller)
 , _sendType(sendType)
 , _titleHeight(st::boxTitleHeight)
 , _list(std::move(list))
-, _sendLimit(peer->slowmodeApplied() ? SendLimit::One : SendLimit::Many)
+, _limits(limits)
 , _sendMenuType(sendMenuType)
-, _allowEmojiWithoutPremium(Data::AllowEmojiWithoutPremium(peer))
+, _check(std::move(check))
 , _caption(this, st::confirmCaptionArea, Ui::InputField::Mode::MultiLine)
 , _prefilledCaptionText(std::move(caption))
 , _scroll(this, st::boxScroll)
@@ -419,6 +455,11 @@ void SendFilesBox::refreshAllAfterChanges(int fromItem, Fn<void()> perform) {
 	{
 		auto sendWay = _sendWay.current();
 		sendWay.setHasCompressedStickers(_list.hasSticker());
+		if (_limits & SendFilesAllow::OnlyOne) {
+			if (_list.files.size() > 1) {
+				sendWay.setGroupFiles(true);
+			}
+		}
 		_sendWay = sendWay;
 	}
 	_inner->resizeToWidth(st::boxWideWidth);
@@ -429,7 +470,7 @@ void SendFilesBox::refreshAllAfterChanges(int fromItem, Fn<void()> perform) {
 void SendFilesBox::openDialogToAddFileToAlbum() {
 	const auto toastParent = Ui::BoxShow(this).toastParent();
 	const auto checkResult = [=](const Ui::PreparedList &list) {
-		if (_sendLimit != SendLimit::One) {
+		if (!(_limits & SendFilesAllow::OnlyOne)) {
 			return true;
 		} else if (!_list.canBeSentInSlowmodeWith(list)) {
 			Ui::Toast::Show(toastParent, tr::lng_slowmode_no_many(tr::now));
@@ -555,20 +596,36 @@ void SendFilesBox::initSendWay() {
 	_sendWay = [&] {
 		auto result = Core::App().settings().sendFilesWay();
 		result.setHasCompressedStickers(_list.hasSticker());
-		if (_sendLimit == SendLimit::One) {
+		if ((_limits & SendFilesAllow::OnlyOne)
+			&& (_list.files.size() > 1)) {
 			result.setGroupFiles(true);
-			return result;
-		} else if (_list.overrideSendImagesAsPhotos == false) {
-			result.setSendImagesAsPhotos(false);
+		}
+		if (_list.overrideSendImagesAsPhotos == false) {
+			if (!(_limits & SendFilesAllow::OnlyOne)
+				|| !_list.hasSticker()) {
+				result.setSendImagesAsPhotos(false);
+			}
 			return result;
 		} else if (_list.overrideSendImagesAsPhotos == true) {
 			result.setSendImagesAsPhotos(true);
+			const auto silent = true;
+			if (!checkWithWay(result, silent)) {
+				result.setSendImagesAsPhotos(false);
+			}
 			return result;
 		}
+		const auto silent = true;
+		if (!checkWithWay(result, silent)) {
+			result.setSendImagesAsPhotos(!result.sendImagesAsPhotos());
+		}
 		return result;
 	}();
 	_sendWay.changes(
 	) | rpl::start_with_next([=](SendFilesWay value) {
+		const auto hidden = [&] {
+			return !_caption || _caption->isHidden();
+		};
+		const auto was = hidden();
 		updateCaptionPlaceholder();
 		updateEmojiPanelGeometry();
 		for (auto &block : _blocks) {
@@ -577,6 +634,10 @@ void SendFilesBox::initSendWay() {
 		if (!hasSendMenu()) {
 			refreshButtons();
 		}
+		if (was != hidden()) {
+			updateBoxSize();
+			updateControlsGeometry();
+		}
 		setInnerFocus();
 	}, lifetime());
 }
@@ -589,7 +650,8 @@ void SendFilesBox::updateCaptionPlaceholder() {
 	if (!_list.canAddCaption(
 			way.groupFiles() && way.sendImagesAsPhotos(),
 			way.sendImagesAsPhotos())
-		&& _sendLimit == SendLimit::One) {
+		&& ((_limits & SendFilesAllow::OnlyOne)
+			|| !(_limits & SendFilesAllow::Texts))) {
 		_caption->hide();
 		if (_emojiToggle) {
 			_emojiToggle->hide();
@@ -695,8 +757,8 @@ void SendFilesBox::pushBlock(int from, int till) {
 				_list.files[index] = std::move(list.files.front());
 			});
 		};
-		const auto checkResult = [=](const Ui::PreparedList &list) {
-			if (_sendLimit != SendLimit::One) {
+		const auto checkSlowmode = [=](const Ui::PreparedList &list) {
+			if (list.files.empty() || !(_limits & SendFilesAllow::OnlyOne)) {
 				return true;
 			}
 			auto removing = std::move(_list.files[index]);
@@ -713,6 +775,37 @@ void SendFilesBox::pushBlock(int from, int till) {
 			}
 			return true;
 		};
+		const auto checkRights = [=](const Ui::PreparedList &list) {
+			if (list.files.empty()) {
+				return true;
+			}
+			auto removing = std::move(_list.files[index]);
+			std::swap(_list.files[index], _list.files.back());
+			_list.files.pop_back();
+			auto way = _sendWay.current();
+			const auto has = _list.hasSticker()
+				|| list.files.front().isSticker();
+			way.setHasCompressedStickers(has);
+			if (_limits & SendFilesAllow::OnlyOne) {
+				way.setGroupFiles(true);
+			}
+			const auto silent = true;
+			if (!checkWith(list, way, silent)
+				&& (!(_limits & SendFilesAllow::OnlyOne) || !has)) {
+				way.setSendImagesAsPhotos(!way.sendImagesAsPhotos());
+			}
+			const auto result = checkWith(list, way);
+			_list.files.push_back(std::move(removing));
+			std::swap(_list.files[index], _list.files.back());
+			if (!result) {
+				return false;
+			}
+			_sendWay = way;
+			return true;
+		};
+		const auto checkResult = [=](const Ui::PreparedList &list) {
+			return checkSlowmode(list) && checkRights(list);
+		};
 		const auto callback = [=](FileDialog::OpenResult &&result) {
 			const auto premium = _controller->session().premium();
 			FileDialogCallback(
@@ -767,7 +860,7 @@ void SendFilesBox::setupSendWayControls() {
 	_sendImagesAsPhotos.create(
 		this,
 		tr::lng_send_compressed(tr::now),
-		asPhotosFirst,
+		_sendWay.current().sendImagesAsPhotos(),
 		st::defaultBoxCheckbox);
 
 	_sendWay.changes(
@@ -777,17 +870,35 @@ void SendFilesBox::setupSendWayControls() {
 	}, lifetime());
 
 	_groupFiles->checkedChanges(
-	) | rpl::start_with_next([=] {
+	) | rpl::start_with_next([=](bool checked) {
 		auto sendWay = _sendWay.current();
-		sendWay.setGroupFiles(_groupFiles->checked());
-		_sendWay = sendWay;
+		if (sendWay.groupFiles() == checked) {
+			return;
+		}
+		sendWay.setGroupFiles(checked);
+		if (checkWithWay(sendWay)) {
+			_sendWay = sendWay;
+		} else {
+			Ui::PostponeCall(_groupFiles.data(), [=] {
+				_groupFiles->setChecked(!checked);
+			});
+		}
 	}, lifetime());
 
 	_sendImagesAsPhotos->checkedChanges(
-	) | rpl::start_with_next([=] {
+	) | rpl::start_with_next([=](bool checked) {
 		auto sendWay = _sendWay.current();
-		sendWay.setSendImagesAsPhotos(_sendImagesAsPhotos->checked());
-		_sendWay = sendWay;
+		if (sendWay.sendImagesAsPhotos() == checked) {
+			return;
+		}
+		sendWay.setSendImagesAsPhotos(checked);
+		if (checkWithWay(sendWay)) {
+			_sendWay = sendWay;
+		} else {
+			Ui::PostponeCall(_sendImagesAsPhotos.data(), [=] {
+				_sendImagesAsPhotos->setChecked(!checked);
+			});
+		}
 	}, lifetime());
 
 	_wayRemember.create(
@@ -811,8 +922,29 @@ void SendFilesBox::setupSendWayControls() {
 		st::editMediaHintLabel);
 }
 
+bool SendFilesBox::checkWithWay(Ui::SendFilesWay way, bool silent) const {
+	return checkWith({}, way, silent);
+}
+
+bool SendFilesBox::checkWith(
+		const Ui::PreparedList &added,
+		Ui::SendFilesWay way,
+		bool silent) const {
+	if (!_check) {
+		return true;
+	}
+	const auto compress = way.sendImagesAsPhotos();
+	auto &already = _list.files;
+	for (const auto &file : ranges::views::concat(already, added.files)) {
+		if (!_check(file, compress, silent)) {
+			return false;
+		}
+	}
+	return true;
+}
+
 void SendFilesBox::updateSendWayControls() {
-	const auto onlyOne = (_sendLimit == SendLimit::One);
+	const auto onlyOne = (_limits & SendFilesAllow::OnlyOne);
 	_groupFiles->setVisible(_list.hasGroupOption(onlyOne));
 	_sendImagesAsPhotos->setVisible(
 		_list.hasSendImagesAsPhotosOption(onlyOne));
@@ -828,7 +960,7 @@ void SendFilesBox::updateSendWayControls() {
 
 void SendFilesBox::setupCaption() {
 	const auto allow = [=](const auto&) {
-		return _allowEmojiWithoutPremium;
+		return (_limits & SendFilesAllow::EmojiWithoutPremium);
 	};
 	InitMessageFieldHandlers(
 		_controller,
@@ -899,7 +1031,7 @@ void SendFilesBox::setupEmojiPanel() {
 		st::emojiPanMinHeight);
 	_emojiPanel->hide();
 	_emojiPanel->selector()->setAllowEmojiWithoutPremium(
-		_allowEmojiWithoutPremium);
+		_limits & SendFilesAllow::EmojiWithoutPremium);
 	_emojiPanel->selector()->emojiChosen(
 	) | rpl::start_with_next([=](ChatHelpers::EmojiChosen data) {
 		Ui::InsertEmojiAtCursor(_caption->textCursor(), data.emoji);
@@ -910,7 +1042,7 @@ void SendFilesBox::setupEmojiPanel() {
 		if (info
 			&& info->setType == Data::StickersType::Emoji
 			&& !_controller->session().premium()
-			&& !_allowEmojiWithoutPremium) {
+			&& !(_limits & SendFilesAllow::EmojiWithoutPremium)) {
 			ShowPremiumPreviewBox(
 				_controller,
 				PremiumPreview::AnimatedEmoji);
@@ -976,14 +1108,11 @@ bool SendFilesBox::addFiles(not_null<const QMimeData*> data) {
 				QString());
 		if (result.error == Ui::PreparedList::Error::None) {
 			return result;
-		} else if (data->hasImage()) {
-			auto image = qvariant_cast<QImage>(data->imageData());
-			if (!image.isNull()) {
-				return Storage::PrepareMediaFromImage(
-					std::move(image),
-					QByteArray(),
-					st::sendMediaPreviewSize);
-			}
+		} else if (auto read = Core::ReadMimeImage(data)) {
+			return Storage::PrepareMediaFromImage(
+				std::move(read.image),
+				std::move(read.content),
+				st::sendMediaPreviewSize);
 		}
 		return result;
 	}();
@@ -1029,7 +1158,20 @@ void SendFilesBox::addFile(Ui::PreparedFile &&file) {
 	// canBeSentInSlowmode checks for non empty filesToProcess.
 	auto saved = base::take(_list.filesToProcess);
 	_list.files.push_back(std::move(file));
-	if (_sendLimit == SendLimit::One && !_list.canBeSentInSlowmode()) {
+	const auto lastOk = [&] {
+		auto way = _sendWay.current();
+		if (_limits & SendFilesAllow::OnlyOne) {
+			way.setGroupFiles(true);
+			if (!_list.canBeSentInSlowmode()) {
+				return false;
+			}
+		} else if (!checkWithWay(way)) {
+			return false;
+		}
+		_sendWay = way;
+		return true;
+	}();
+	if (!lastOk) {
 		_list.files.pop_back();
 	}
 	_list.filesToProcess = std::move(saved);
@@ -1061,7 +1203,7 @@ void SendFilesBox::refreshTitleText() {
 
 void SendFilesBox::updateBoxSize() {
 	auto footerHeight = 0;
-	if (_caption) {
+	if (_caption && !_caption->isHidden()) {
 		footerHeight += st::boxPhotoCaptionSkip + _caption->height();
 	}
 	const auto pairs = std::array<std::pair<RpWidget*, int>, 4>{ {
@@ -1116,7 +1258,7 @@ void SendFilesBox::resizeEvent(QResizeEvent *e) {
 
 void SendFilesBox::updateControlsGeometry() {
 	auto bottom = height();
-	if (_caption) {
+	if (_caption && !_caption->isHidden()) {
 		_caption->resize(st::sendMediaPreviewSize, _caption->height());
 		_caption->moveToLeft(
 			st::boxPhotoPadding.left(),
