@@ -16,12 +16,14 @@ class Session;
 
 namespace Settings {
 
-class Sessions : public Section {
+class Sessions : public Section<Sessions> {
 public:
 	Sessions(
 		QWidget *parent,
 		not_null<Window::SessionController*> controller);
 
+	[[nodiscard]] rpl::producer<QString> title() override;
+
 private:
 	void setupContent(not_null<Window::SessionController*> controller);
 
