@@ -854,7 +854,7 @@ void ShareBox::Inner::loadProfilePhotos(int yFrom) {
 				if (((*i)->index() * _rowHeight) >= yTo) {
 					break;
 				}
-				(*i)->entry()->loadUserpic();
+				(*i)->entry()->chatListPreloadData();
 			}
 		}
 	} else if (!_filtered.empty()) {
@@ -865,7 +865,7 @@ void ShareBox::Inner::loadProfilePhotos(int yFrom) {
 			if (to > _filtered.size()) to = _filtered.size();
 
 			for (; from < to; ++from) {
-				_filtered[from]->entry()->loadUserpic();
+				_filtered[from]->entry()->chatListPreloadData();
 			}
 		}
 	}
