@@ -9,6 +9,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 
 namespace Ui {
 class GenericBox;
+class VerticalLayout;
 } // namespace Ui
 
 namespace Main {
@@ -18,3 +19,18 @@ class Session;
 void UsernamesBox(
 	not_null<Ui::GenericBox*> box,
 	not_null<Main::Session*> session);
+
+struct UsernameCheckInfo final {
+	enum class Type {
+		Good,
+		Error,
+		Default,
+		PurchaseAvailable,
+	};
+	Type type;
+	TextWithEntities text;
+};
+
+void AddUsernameCheckLabel(
+	not_null<Ui::VerticalLayout*> container,
+	rpl::producer<UsernameCheckInfo> checkInfo);
