@@ -37,6 +37,10 @@ public:
 		return _content.lifetime();
 	}
 
+	void setMirrored(bool mirrored) {
+		_mirrored = mirrored;
+	}
+
 private:
 	void setup();
 	void paint();
@@ -59,6 +63,7 @@ private:
 	RectPart _corner = RectPart::None;
 	bool _dragging = false;
 	bool _geometryDirty = false;
+	bool _mirrored = true;
 
 };
 
