@@ -13,6 +13,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 class PeerData;
 
 namespace Ui {
+class Show;
 class BoxContent;
 } // namespace Ui
 
@@ -36,8 +37,7 @@ public:
 	void start(
 		not_null<PeerData*> peer,
 		Context context,
-		Fn<void(object_ptr<Ui::BoxContent>)> showBox,
-		Fn<void(QString)> showToast,
+		std::shared_ptr<Ui::Show> show,
 		Fn<void(JoinInfo)> done,
 		PeerData *changingJoinAsFrom = nullptr);
 
@@ -48,8 +48,7 @@ private:
 
 	struct ChannelsListRequest {
 		not_null<PeerData*> peer;
-		Fn<void(object_ptr<Ui::BoxContent>)> showBox;
-		Fn<void(QString)> showToast;
+		std::shared_ptr<Ui::Show> show;
 		Fn<void(JoinInfo)> done;
 		base::has_weak_ptr guard;
 		QPointer<Ui::BoxContent> box;
