@@ -61,6 +61,8 @@ public:
 	}
 
 	[[nodiscard]] MembersRow *lookupRow(not_null<PeerData*> peer) const;
+	[[nodiscard]] not_null<MembersRow*> rtmpFakeRow(
+		not_null<PeerData*> peer) const;
 
 	void setMode(PanelMode mode);
 	[[nodiscard]] QRect getInnerGeometry() const;
@@ -86,6 +88,11 @@ private:
 	void peerListFinishSelectedRowsBunch() override;
 	void peerListSetDescription(
 		object_ptr<Ui::FlatLabel> description) override;
+	void peerListShowBox(
+		object_ptr<Ui::BoxContent> content,
+		Ui::LayerOptions options = Ui::LayerOption::KeepOther) override;
+	void peerListHideLayer() override;
+	not_null<QWidget*> peerListToastParent() override;
 
 	void setupAddMember(not_null<GroupCall*> call);
 	void resizeToList();
@@ -108,6 +115,8 @@ private:
 	ListWidget *_list = nullptr;
 	rpl::event_stream<> _addMemberRequests;
 
+	mutable std::unique_ptr<MembersRow> _rtmpFakeRow;
+
 	rpl::variable<bool> _canInviteByLink;
 	rpl::variable<bool> _canAddMembers;
 
