@@ -255,7 +255,7 @@ void BotKeyboard::clickHandlerPressedChanged(const ClickHandlerPtr &p, bool pres
 bool BotKeyboard::updateMarkup(HistoryItem *to, bool force) {
 	if (!to || !to->definesReplyKeyboard()) {
 		if (_wasForMsgId.msg) {
-			_maximizeSize = _singleUse = _forceReply = false;
+			_maximizeSize = _singleUse = _forceReply = _persistent = false;
 			_wasForMsgId = FullMsgId();
 			_placeholder = QString();
 			_impl = nullptr;
@@ -275,6 +275,7 @@ bool BotKeyboard::updateMarkup(HistoryItem *to, bool force) {
 	_forceReply = markupFlags & ReplyMarkupFlag::ForceReply;
 	_maximizeSize = !(markupFlags & ReplyMarkupFlag::Resize);
 	_singleUse = _forceReply || (markupFlags & ReplyMarkupFlag::SingleUse);
+	_persistent = (markupFlags & ReplyMarkupFlag::Persistent);
 
 	if (const auto markup = to->Get<HistoryMessageReplyMarkup>()) {
 		_placeholder = markup->data.placeholder;
@@ -326,6 +327,10 @@ bool BotKeyboard::singleUse() const {
 	return _singleUse;
 }
 
+bool BotKeyboard::persistent() const {
+	return _persistent;
+}
+
 void BotKeyboard::updateStyle(int newWidth) {
 	if (!_impl) return;
 
