@@ -24,6 +24,7 @@ class Session;
 
 namespace Window {
 class SessionController;
+enum class GifPauseReason;
 } // namespace Window
 
 namespace Ui {
@@ -43,18 +44,28 @@ Fn<bool(
 		not_null<Main::Session*> session,
 		not_null<Ui::InputField*> field,
 		const style::InputField *fieldStyle = nullptr);
+void InitMessageFieldHandlers(
+	not_null<Main::Session*> session,
+	std::shared_ptr<Ui::Show> show,
+	not_null<Ui::InputField*> field,
+	Fn<bool()> customEmojiPaused,
+	Fn<bool(not_null<DocumentData*>)> allowPremiumEmoji = nullptr,
+	const style::InputField *fieldStyle = nullptr);
+void InitMessageFieldHandlers(
+	not_null<Window::SessionController*> controller,
+	not_null<Ui::InputField*> field,
+	Window::GifPauseReason pauseReasonLevel,
+	Fn<bool(not_null<DocumentData*>)> allowPremiumEmoji = nullptr);
 void InitMessageField(
 	not_null<Window::SessionController*> controller,
-	not_null<Ui::InputField*> field);
+	not_null<Ui::InputField*> field,
+	Fn<bool(not_null<DocumentData*>)> allowPremiumEmoji);
 
 void InitSpellchecker(
 	std::shared_ptr<Ui::Show> show,
 	not_null<Main::Session*> session,
 	not_null<Ui::InputField*> field,
 	bool skipDictionariesManager = false);
-void InitSpellchecker(
-	not_null<Window::SessionController*> controller,
-	not_null<Ui::InputField*> field);
 
 bool HasSendText(not_null<const Ui::InputField*> field);
 
@@ -111,3 +122,7 @@ private:
 	base::qt_connection _connection;
 
 };
+
+[[nodiscard]] base::unique_qptr<Ui::RpWidget> CreateDisabledFieldView(
+	QWidget *parent,
+	not_null<PeerData*> peer);
