@@ -11,6 +11,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include <QtCore/QString>
 #include <QtCore/QStringList>
 #include <QtCore/QMimeType>
+#include <QtGui/QImage>
 
 class QMimeData;
 
@@ -52,4 +53,17 @@ private:
 [[nodiscard]] std::shared_ptr<QMimeData> ShareMimeMediaData(
 	not_null<const QMimeData*> original);
 
+struct MimeImageData {
+	QImage image;
+	QByteArray content;
+
+	[[nodiscard]] bool empty() const {
+		return image.isNull();
+	}
+	explicit operator bool() const {
+		return !empty();
+	}
+};
+[[nodiscard]] MimeImageData ReadMimeImage(not_null<const QMimeData*> data);
+
 } // namespace Core
