@@ -239,17 +239,17 @@ void Sandbox::setupScreenScale() {
 	const auto basePair = screen->handle()->logicalBaseDpi();
 	const auto base = (basePair.first + basePair.second) * 0.5;
 	const auto screenScaleExact = dpi / base;
-	const auto screenScale = int(base::SafeRound(screenScaleExact * 4)) * 25;
+	const auto screenScale = int(base::SafeRound(screenScaleExact * 20)) * 5;
 	LOG(("Primary screen DPI: %1, Base: %2.").arg(dpi).arg(base));
 	LOG(("Computed screen scale: %1").arg(screenScale));
 	if (Platform::IsMac()) {
 		// 110% for Retina screens by default.
-		cSetScreenScale((useRatio == 2) ? 110 : 100);
+		cSetScreenScale((useRatio == 2) ? 110 : style::kScaleDefault);
 	} else {
 		const auto clamped = std::clamp(
 			screenScale * useRatio,
-			50 * useRatio,
-			300);
+			style::kScaleMin * useRatio,
+			style::kScaleMax);
 		cSetScreenScale(int(base::SafeRound(clamped * 1. / useRatio)));
 	}
 	LOG(("DevicePixelRatio: %1").arg(useRatio));
