@@ -16,6 +16,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "platform/platform_specific.h"
 #include "base/parse_helper.h"
 
+#include <QAction>
 #include <QShortcut>
 #include <QtCore/QJsonDocument>
 #include <QtCore/QJsonObject>
@@ -143,11 +144,13 @@ public:
 	void fill();
 	void clear();
 
-	[[nodiscard]] std::vector<Command> lookup(int shortcutId) const;
+	[[nodiscard]] std::vector<Command> lookup(
+		not_null<QObject*> object) const;
 	void toggleMedia(bool toggled);
 	void toggleSupport(bool toggled);
+	void listen(not_null<QWidget*> widget);
 
-	const QStringList &errors() const;
+	[[nodiscard]] const QStringList &errors() const;
 
 private:
 	void fillDefaults();
@@ -156,15 +159,15 @@ private:
 
 	void set(const QString &keys, Command command, bool replace = false);
 	void remove(const QString &keys);
-	void unregister(base::unique_qptr<QShortcut> shortcut);
+	void unregister(base::unique_qptr<QAction> shortcut);
 
 	QStringList _errors;
 
-	base::flat_map<QKeySequence, base::unique_qptr<QShortcut>> _shortcuts;
-	base::flat_multi_map<int, Command> _commandByShortcutId;
+	base::flat_map<QKeySequence, base::unique_qptr<QAction>> _shortcuts;
+	base::flat_multi_map<not_null<QObject*>, Command> _commandByObject;
 
-	base::flat_set<QShortcut*> _mediaShortcuts;
-	base::flat_set<QShortcut*> _supportShortcuts;
+	base::flat_set<QAction*> _mediaShortcuts;
+	base::flat_set<QAction*> _supportShortcuts;
 
 };
 
@@ -227,7 +230,7 @@ void Manager::fill() {
 void Manager::clear() {
 	_errors.clear();
 	_shortcuts.clear();
-	_commandByShortcutId.clear();
+	_commandByObject.clear();
 	_mediaShortcuts.clear();
 	_supportShortcuts.clear();
 }
@@ -236,11 +239,11 @@ const QStringList &Manager::errors() const {
 	return _errors;
 }
 
-std::vector<Command> Manager::lookup(int shortcutId) const {
+std::vector<Command> Manager::lookup(not_null<QObject*> object) const {
 	auto result = std::vector<Command>();
-	auto i = _commandByShortcutId.findFirst(shortcutId);
-	const auto end = _commandByShortcutId.end();
-	for (; i != end && (i->first == shortcutId); ++i) {
+	auto i = _commandByObject.findFirst(object);
+	const auto end = _commandByObject.end();
+	for (; i != end && (i->first == object); ++i) {
 		result.push_back(i->second);
 	}
 	return result;
@@ -258,6 +261,12 @@ void Manager::toggleSupport(bool toggled) {
 	}
 }
 
+void Manager::listen(not_null<QWidget*> widget) {
+	for (const auto &[keys, shortcut] : _shortcuts) {
+		widget->addAction(shortcut.get());
+	}
+}
+
 bool Manager::readCustomFile() {
 	// read custom shortcuts from file if it exists or write an empty custom shortcuts file
 	QFile file(CustomFilePath());
@@ -412,10 +421,10 @@ void Manager::writeDefaultFile() {
 	shortcuts.push_back(version);
 
 	for (const auto &[sequence, shortcut] : _shortcuts) {
-		const auto shortcutId = shortcut->id();
-		auto i = _commandByShortcutId.findFirst(shortcutId);
-		const auto end = _commandByShortcutId.end();
-		for (; i != end && i->first == shortcutId; ++i) {
+		const auto object = shortcut.get();
+		auto i = _commandByObject.findFirst(object);
+		const auto end = _commandByObject.end();
+		for (; i != end && i->first == object; ++i) {
 			const auto j = CommandNames.find(i->second);
 			if (j != CommandNames.end()) {
 				QJsonObject entry;
@@ -441,12 +450,9 @@ void Manager::set(const QString &keys, Command command, bool replace) {
 		_errors.push_back(u"Could not derive key sequence '%1'!"_q.arg(keys));
 		return;
 	}
-	auto shortcut = base::make_unique_q<QShortcut>(
-		result,
-		Core::App().primaryWindow()->widget().get(),
-		nullptr,
-		nullptr,
-		Qt::ApplicationShortcut);
+	auto shortcut = base::make_unique_q<QAction>();
+	shortcut->setShortcut(result);
+	shortcut->setShortcutContext(Qt::ApplicationShortcut);
 	if (!AutoRepeatCommands.contains(command)) {
 		shortcut->setAutoRepeat(false);
 	}
@@ -455,20 +461,16 @@ void Manager::set(const QString &keys, Command command, bool replace) {
 	if (isMediaShortcut || isSupportShortcut) {
 		shortcut->setEnabled(false);
 	}
-	auto id = shortcut->id();
+	auto object = shortcut.get();
 	auto i = _shortcuts.find(result);
 	if (i == end(_shortcuts)) {
 		i = _shortcuts.emplace(result, std::move(shortcut)).first;
 	} else if (replace) {
 		unregister(std::exchange(i->second, std::move(shortcut)));
 	} else {
-		id = i->second->id();
+		object = i->second.get();
 	}
-	if (!id) {
-		_errors.push_back(u"Could not create shortcut '%1'!"_q.arg(keys));
-		return;
-	}
-	_commandByShortcutId.emplace(id, command);
+	_commandByObject.emplace(object, command);
 	if (!shortcut && isMediaShortcut) {
 		_mediaShortcuts.emplace(i->second.get());
 	}
@@ -494,9 +496,9 @@ void Manager::remove(const QString &keys) {
 	}
 }
 
-void Manager::unregister(base::unique_qptr<QShortcut> shortcut) {
+void Manager::unregister(base::unique_qptr<QAction> shortcut) {
 	if (shortcut) {
-		_commandByShortcutId.erase(shortcut->id());
+		_commandByObject.erase(shortcut.get());
 		_mediaShortcuts.erase(shortcut.get());
 		_supportShortcuts.erase(shortcut.get());
 	}
@@ -560,8 +562,10 @@ const QStringList &Errors() {
 	return Data.errors();
 }
 
-bool HandleEvent(not_null<QShortcutEvent*> event) {
-	return Launch(Data.lookup(event->shortcutId()));
+bool HandleEvent(
+		not_null<QObject*> object,
+		not_null<QShortcutEvent*> event) {
+	return Launch(Data.lookup(object));
 }
 
 void ToggleMediaShortcuts(bool toggled) {
@@ -576,4 +580,8 @@ void Finish() {
 	Data.clear();
 }
 
+void Listen(not_null<QWidget*> widget) {
+	Data.listen(widget);
+}
+
 } // namespace Shortcuts
