@@ -339,12 +339,12 @@ namespace {
 
 QString translitLetterRusEng(QChar letter, QChar next, int32 &toSkip) {
 	if (fastDoubleLetterRusEng.isEmpty()) {
-		fastDoubleLetterRusEng.insert((QString::fromUtf8("Ы").at(0).unicode() << 16) | QString::fromUtf8("й").at(0).unicode(), qsl("Y"));
-		fastDoubleLetterRusEng.insert((QString::fromUtf8("и").at(0).unicode() << 16) | QString::fromUtf8("я").at(0).unicode(), qsl("ia"));
-		fastDoubleLetterRusEng.insert((QString::fromUtf8("и").at(0).unicode() << 16) | QString::fromUtf8("й").at(0).unicode(), qsl("y"));
-		fastDoubleLetterRusEng.insert((QString::fromUtf8("к").at(0).unicode() << 16) | QString::fromUtf8("с").at(0).unicode(), qsl("x"));
-		fastDoubleLetterRusEng.insert((QString::fromUtf8("ы").at(0).unicode() << 16) | QString::fromUtf8("й").at(0).unicode(), qsl("y"));
-		fastDoubleLetterRusEng.insert((QString::fromUtf8("ь").at(0).unicode() << 16) | QString::fromUtf8("е").at(0).unicode(), qsl("ye"));
+		fastDoubleLetterRusEng.insert((QString::fromUtf8("Ы").at(0).unicode() << 16) | QString::fromUtf8("й").at(0).unicode(), u"Y"_q);
+		fastDoubleLetterRusEng.insert((QString::fromUtf8("и").at(0).unicode() << 16) | QString::fromUtf8("я").at(0).unicode(), u"ia"_q);
+		fastDoubleLetterRusEng.insert((QString::fromUtf8("и").at(0).unicode() << 16) | QString::fromUtf8("й").at(0).unicode(), u"y"_q);
+		fastDoubleLetterRusEng.insert((QString::fromUtf8("к").at(0).unicode() << 16) | QString::fromUtf8("с").at(0).unicode(), u"x"_q);
+		fastDoubleLetterRusEng.insert((QString::fromUtf8("ы").at(0).unicode() << 16) | QString::fromUtf8("й").at(0).unicode(), u"y"_q);
+		fastDoubleLetterRusEng.insert((QString::fromUtf8("ь").at(0).unicode() << 16) | QString::fromUtf8("е").at(0).unicode(), u"ye"_q);
 	}
 	QMap<uint32, QString>::const_iterator i = fastDoubleLetterRusEng.constFind((letter.unicode() << 16) | next.unicode());
 	if (i != fastDoubleLetterRusEng.cend()) {
@@ -354,81 +354,81 @@ QString translitLetterRusEng(QChar letter, QChar next, int32 &toSkip) {
 
 	toSkip = 1;
 	if (fastLetterRusEng.isEmpty()) {
-		fastLetterRusEng.insert(QString::fromUtf8("А").at(0), qsl("A"));
-		fastLetterRusEng.insert(QString::fromUtf8("Б").at(0), qsl("B"));
-		fastLetterRusEng.insert(QString::fromUtf8("В").at(0), qsl("V"));
-		fastLetterRusEng.insert(QString::fromUtf8("Г").at(0), qsl("G"));
-		fastLetterRusEng.insert(QString::fromUtf8("Ґ").at(0), qsl("G"));
-		fastLetterRusEng.insert(QString::fromUtf8("Д").at(0), qsl("D"));
-		fastLetterRusEng.insert(QString::fromUtf8("Е").at(0), qsl("E"));
-		fastLetterRusEng.insert(QString::fromUtf8("Є").at(0), qsl("Ye"));
-		fastLetterRusEng.insert(QString::fromUtf8("Ё").at(0), qsl("Yo"));
-		fastLetterRusEng.insert(QString::fromUtf8("Ж").at(0), qsl("Zh"));
-		fastLetterRusEng.insert(QString::fromUtf8("З").at(0), qsl("Z"));
-		fastLetterRusEng.insert(QString::fromUtf8("И").at(0), qsl("I"));
-		fastLetterRusEng.insert(QString::fromUtf8("Ї").at(0), qsl("Yi"));
-		fastLetterRusEng.insert(QString::fromUtf8("І").at(0), qsl("I"));
-		fastLetterRusEng.insert(QString::fromUtf8("Й").at(0), qsl("J"));
-		fastLetterRusEng.insert(QString::fromUtf8("К").at(0), qsl("K"));
-		fastLetterRusEng.insert(QString::fromUtf8("Л").at(0), qsl("L"));
-		fastLetterRusEng.insert(QString::fromUtf8("М").at(0), qsl("M"));
-		fastLetterRusEng.insert(QString::fromUtf8("Н").at(0), qsl("N"));
-		fastLetterRusEng.insert(QString::fromUtf8("О").at(0), qsl("O"));
-		fastLetterRusEng.insert(QString::fromUtf8("П").at(0), qsl("P"));
-		fastLetterRusEng.insert(QString::fromUtf8("Р").at(0), qsl("R"));
-		fastLetterRusEng.insert(QString::fromUtf8("С").at(0), qsl("S"));
-		fastLetterRusEng.insert(QString::fromUtf8("Т").at(0), qsl("T"));
-		fastLetterRusEng.insert(QString::fromUtf8("У").at(0), qsl("U"));
-		fastLetterRusEng.insert(QString::fromUtf8("Ў").at(0), qsl("W"));
-		fastLetterRusEng.insert(QString::fromUtf8("Ф").at(0), qsl("F"));
-		fastLetterRusEng.insert(QString::fromUtf8("Х").at(0), qsl("Kh"));
-		fastLetterRusEng.insert(QString::fromUtf8("Ц").at(0), qsl("Ts"));
-		fastLetterRusEng.insert(QString::fromUtf8("Ч").at(0), qsl("Ch"));
-		fastLetterRusEng.insert(QString::fromUtf8("Ш").at(0), qsl("Sh"));
-		fastLetterRusEng.insert(QString::fromUtf8("Щ").at(0), qsl("Sch"));
-		fastLetterRusEng.insert(QString::fromUtf8("Э").at(0), qsl("E"));
-		fastLetterRusEng.insert(QString::fromUtf8("Ю").at(0), qsl("Yu"));
-		fastLetterRusEng.insert(QString::fromUtf8("Я").at(0), qsl("Ya"));
-		fastLetterRusEng.insert(QString::fromUtf8("Ў").at(0), qsl("W"));
-		fastLetterRusEng.insert(QString::fromUtf8("а").at(0), qsl("a"));
-		fastLetterRusEng.insert(QString::fromUtf8("б").at(0), qsl("b"));
-		fastLetterRusEng.insert(QString::fromUtf8("в").at(0), qsl("v"));
-		fastLetterRusEng.insert(QString::fromUtf8("г").at(0), qsl("g"));
-		fastLetterRusEng.insert(QString::fromUtf8("ґ").at(0), qsl("g"));
-		fastLetterRusEng.insert(QString::fromUtf8("д").at(0), qsl("d"));
-		fastLetterRusEng.insert(QString::fromUtf8("е").at(0), qsl("e"));
-		fastLetterRusEng.insert(QString::fromUtf8("є").at(0), qsl("ye"));
-		fastLetterRusEng.insert(QString::fromUtf8("ё").at(0), qsl("yo"));
-		fastLetterRusEng.insert(QString::fromUtf8("ж").at(0), qsl("zh"));
-		fastLetterRusEng.insert(QString::fromUtf8("з").at(0), qsl("z"));
-		fastLetterRusEng.insert(QString::fromUtf8("й").at(0), qsl("y"));
-		fastLetterRusEng.insert(QString::fromUtf8("ї").at(0), qsl("yi"));
-		fastLetterRusEng.insert(QString::fromUtf8("і").at(0), qsl("i"));
-		fastLetterRusEng.insert(QString::fromUtf8("л").at(0), qsl("l"));
-		fastLetterRusEng.insert(QString::fromUtf8("м").at(0), qsl("m"));
-		fastLetterRusEng.insert(QString::fromUtf8("н").at(0), qsl("n"));
-		fastLetterRusEng.insert(QString::fromUtf8("о").at(0), qsl("o"));
-		fastLetterRusEng.insert(QString::fromUtf8("п").at(0), qsl("p"));
-		fastLetterRusEng.insert(QString::fromUtf8("р").at(0), qsl("r"));
-		fastLetterRusEng.insert(QString::fromUtf8("с").at(0), qsl("s"));
-		fastLetterRusEng.insert(QString::fromUtf8("т").at(0), qsl("t"));
-		fastLetterRusEng.insert(QString::fromUtf8("у").at(0), qsl("u"));
-		fastLetterRusEng.insert(QString::fromUtf8("ў").at(0), qsl("w"));
-		fastLetterRusEng.insert(QString::fromUtf8("ф").at(0), qsl("f"));
-		fastLetterRusEng.insert(QString::fromUtf8("х").at(0), qsl("kh"));
-		fastLetterRusEng.insert(QString::fromUtf8("ц").at(0), qsl("ts"));
-		fastLetterRusEng.insert(QString::fromUtf8("ч").at(0), qsl("ch"));
-		fastLetterRusEng.insert(QString::fromUtf8("ш").at(0), qsl("sh"));
-		fastLetterRusEng.insert(QString::fromUtf8("щ").at(0), qsl("sch"));
+		fastLetterRusEng.insert(QString::fromUtf8("А").at(0), u"A"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("Б").at(0), u"B"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("В").at(0), u"V"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("Г").at(0), u"G"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("Ґ").at(0), u"G"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("Д").at(0), u"D"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("Е").at(0), u"E"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("Є").at(0), u"Ye"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("Ё").at(0), u"Yo"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("Ж").at(0), u"Zh"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("З").at(0), u"Z"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("И").at(0), u"I"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("Ї").at(0), u"Yi"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("І").at(0), u"I"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("Й").at(0), u"J"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("К").at(0), u"K"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("Л").at(0), u"L"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("М").at(0), u"M"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("Н").at(0), u"N"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("О").at(0), u"O"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("П").at(0), u"P"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("Р").at(0), u"R"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("С").at(0), u"S"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("Т").at(0), u"T"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("У").at(0), u"U"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("Ў").at(0), u"W"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("Ф").at(0), u"F"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("Х").at(0), u"Kh"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("Ц").at(0), u"Ts"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("Ч").at(0), u"Ch"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("Ш").at(0), u"Sh"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("Щ").at(0), u"Sch"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("Э").at(0), u"E"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("Ю").at(0), u"Yu"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("Я").at(0), u"Ya"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("Ў").at(0), u"W"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("а").at(0), u"a"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("б").at(0), u"b"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("в").at(0), u"v"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("г").at(0), u"g"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("ґ").at(0), u"g"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("д").at(0), u"d"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("е").at(0), u"e"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("є").at(0), u"ye"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("ё").at(0), u"yo"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("ж").at(0), u"zh"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("з").at(0), u"z"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("й").at(0), u"y"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("ї").at(0), u"yi"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("і").at(0), u"i"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("л").at(0), u"l"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("м").at(0), u"m"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("н").at(0), u"n"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("о").at(0), u"o"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("п").at(0), u"p"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("р").at(0), u"r"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("с").at(0), u"s"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("т").at(0), u"t"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("у").at(0), u"u"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("ў").at(0), u"w"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("ф").at(0), u"f"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("х").at(0), u"kh"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("ц").at(0), u"ts"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("ч").at(0), u"ch"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("ш").at(0), u"sh"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("щ").at(0), u"sch"_q);
 		fastLetterRusEng.insert(QString::fromUtf8("ъ").at(0), QString());
-		fastLetterRusEng.insert(QString::fromUtf8("э").at(0), qsl("e"));
-		fastLetterRusEng.insert(QString::fromUtf8("ю").at(0), qsl("yu"));
-		fastLetterRusEng.insert(QString::fromUtf8("я").at(0), qsl("ya"));
-		fastLetterRusEng.insert(QString::fromUtf8("ў").at(0), qsl("w"));
-		fastLetterRusEng.insert(QString::fromUtf8("Ы").at(0), qsl("Y"));
-		fastLetterRusEng.insert(QString::fromUtf8("и").at(0), qsl("i"));
-		fastLetterRusEng.insert(QString::fromUtf8("к").at(0), qsl("k"));
-		fastLetterRusEng.insert(QString::fromUtf8("ы").at(0), qsl("y"));
+		fastLetterRusEng.insert(QString::fromUtf8("э").at(0), u"e"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("ю").at(0), u"yu"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("я").at(0), u"ya"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("ў").at(0), u"w"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("Ы").at(0), u"Y"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("и").at(0), u"i"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("к").at(0), u"k"_q);
+		fastLetterRusEng.insert(QString::fromUtf8("ы").at(0), u"y"_q);
 		fastLetterRusEng.insert(QString::fromUtf8("ь").at(0), QString());
 	}
 	QHash<QChar, QString>::const_iterator j = fastLetterRusEng.constFind(letter);
@@ -440,16 +440,16 @@ QString translitLetterRusEng(QChar letter, QChar next, int32 &toSkip) {
 
 QString translitRusEng(const QString &rus) {
 	if (fastRusEng.isEmpty()) {
-		fastRusEng.insert(QString::fromUtf8("Александр"), qsl("Alexander"));
-		fastRusEng.insert(QString::fromUtf8("александр"), qsl("alexander"));
-		fastRusEng.insert(QString::fromUtf8("Филипп"), qsl("Philip"));
-		fastRusEng.insert(QString::fromUtf8("филипп"), qsl("philip"));
-		fastRusEng.insert(QString::fromUtf8("Пётр"), qsl("Petr"));
-		fastRusEng.insert(QString::fromUtf8("пётр"), qsl("petr"));
-		fastRusEng.insert(QString::fromUtf8("Гай"), qsl("Gai"));
-		fastRusEng.insert(QString::fromUtf8("гай"), qsl("gai"));
-		fastRusEng.insert(QString::fromUtf8("Ильин"), qsl("Ilyin"));
-		fastRusEng.insert(QString::fromUtf8("ильин"), qsl("ilyin"));
+		fastRusEng.insert(QString::fromUtf8("Александр"), u"Alexander"_q);
+		fastRusEng.insert(QString::fromUtf8("александр"), u"alexander"_q);
+		fastRusEng.insert(QString::fromUtf8("Филипп"), u"Philip"_q);
+		fastRusEng.insert(QString::fromUtf8("филипп"), u"philip"_q);
+		fastRusEng.insert(QString::fromUtf8("Пётр"), u"Petr"_q);
+		fastRusEng.insert(QString::fromUtf8("пётр"), u"petr"_q);
+		fastRusEng.insert(QString::fromUtf8("Гай"), u"Gai"_q);
+		fastRusEng.insert(QString::fromUtf8("гай"), u"gai"_q);
+		fastRusEng.insert(QString::fromUtf8("Ильин"), u"Ilyin"_q);
+		fastRusEng.insert(QString::fromUtf8("ильин"), u"ilyin"_q);
 	}
 	QMap<QString, QString>::const_iterator i = fastRusEng.constFind(rus);
 	if (i != fastRusEng.cend()) {
