@@ -7,11 +7,9 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 */
 #pragma once
 
-#include "logs.h"
 #include "base/basic_types.h"
 #include "base/flags.h"
 #include "base/algorithm.h"
-#include "base/assertion.h"
 #include "base/bytes.h"
 
 #include <crl/crl_time.h>
@@ -177,57 +175,3 @@ inline int ceilclamp(float64 value, int32 step, int32 lowest, int32 highest) {
 		lowest,
 		highest);
 }
-
-static int32 FullArcLength = 360 * 16;
-static int32 QuarterArcLength = (FullArcLength / 4);
-static int32 MinArcLength = (FullArcLength / 360);
-static int32 AlmostFullArcLength = (FullArcLength - MinArcLength);
-
-// This pointer is used for global non-POD variables that are allocated
-// on demand by createIfNull(lambda) and are never automatically freed.
-template <typename T>
-class NeverFreedPointer {
-public:
-	NeverFreedPointer() = default;
-	NeverFreedPointer(const NeverFreedPointer<T> &other) = delete;
-	NeverFreedPointer &operator=(const NeverFreedPointer<T> &other) = delete;
-
-	template <typename... Args>
-	void createIfNull(Args&&... args) {
-		if (isNull()) {
-			reset(new T(std::forward<Args>(args)...));
-		}
-	};
-
-	T *data() const {
-		return _p;
-	}
-	T *release() {
-		return base::take(_p);
-	}
-	void reset(T *p = nullptr) {
-		delete _p;
-		_p = p;
-	}
-	bool isNull() const {
-		return data() == nullptr;
-	}
-
-	void clear() {
-		reset();
-	}
-	T *operator->() const {
-		return data();
-	}
-	T &operator*() const {
-		Assert(!isNull());
-		return *data();
-	}
-	explicit operator bool() const {
-		return !isNull();
-	}
-
-private:
-	T *_p;
-
-};
