@@ -63,11 +63,6 @@ ChatAdminRightsInfo ChatData::defaultAdminRights(not_null<UserData*> user) {
 		| (isCreator ? Flag::AddAdmins : Flag(0)));
 }
 
-bool ChatData::canWrite() const {
-	// Duplicated in Data::CanWriteValue().
-	return amIn() && !amRestricted(ChatRestriction::SendMessages);
-}
-
 bool ChatData::allowsForwarding() const {
 	return !(flags() & Flag::NoForwards);
 }
@@ -99,10 +94,6 @@ bool ChatData::canAddMembers() const {
 	return amIn() && !amRestricted(ChatRestriction::AddParticipants);
 }
 
-bool ChatData::canSendPolls() const {
-	return amIn() && !amRestricted(ChatRestriction::SendPolls);
-}
-
 bool ChatData::canAddAdmins() const {
 	return amIn() && amCreator();
 }
@@ -479,6 +470,7 @@ void ApplyChatUpdate(not_null<ChatData*> chat, const MTPDchatFull &update) {
 	}
 	chat->checkFolder(update.vfolder_id().value_or_empty());
 	chat->setThemeEmoji(qs(update.vtheme_emoticon().value_or_empty()));
+	chat->setTranslationDisabled(update.is_translations_disabled());
 	if (const auto allowed = update.vavailable_reactions()) {
 		chat->setAllowedReactions(Data::Parse(*allowed));
 	} else {
