@@ -44,17 +44,6 @@ struct CloudFile final {
 	base::flags<Flag> flags;
 };
 
-class CloudImageView final {
-public:
-	void set(not_null<Main::Session*> session, QImage image);
-
-	[[nodiscard]] Image *image();
-
-private:
-	std::optional<Image> _image;
-
-};
-
 class CloudImage final {
 public:
 	CloudImage();
@@ -79,14 +68,16 @@ public:
 	[[nodiscard]] const ImageLocation &location() const;
 	[[nodiscard]] int byteSize() const;
 
-	[[nodiscard]] std::shared_ptr<CloudImageView> createView();
-	[[nodiscard]] std::shared_ptr<CloudImageView> activeView() const;
+	[[nodiscard]] std::shared_ptr<QImage> createView();
+	[[nodiscard]] std::shared_ptr<QImage> activeView() const;
 	[[nodiscard]] bool isCurrentView(
-		const std::shared_ptr<CloudImageView> &view) const;
+		const std::shared_ptr<QImage> &view) const;
 
 private:
+	void setToActive(not_null<Main::Session*> session, QImage image);
+
 	CloudFile _file;
-	std::weak_ptr<CloudImageView> _view;
+	std::weak_ptr<QImage> _view;
 
 };
 
