@@ -18,6 +18,9 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "storage/file_download.h"
 #include "ui/image/image.h"
 
+#include <QtGui/QGuiApplication>
+#include <QtGui/QClipboard>
+
 namespace Data {
 
 PhotoMedia::PhotoMedia(not_null<PhotoData*> owner)
@@ -198,8 +201,7 @@ bool PhotoMedia::saveToFile(const QString &path) {
 		QFile f(path);
 		return f.open(QIODevice::WriteOnly)
 			&& (f.write(video) == video.size());
-	} else if (const auto photo = imageBytes(large)
-		; !photo.isEmpty()) {
+	} else if (const auto photo = imageBytes(large); !photo.isEmpty()) {
 		QFile f(path);
 		return f.open(QIODevice::WriteOnly)
 			&& (f.write(photo) == photo.size());
@@ -210,4 +212,24 @@ bool PhotoMedia::saveToFile(const QString &path) {
 	return false;
 }
 
+bool PhotoMedia::setToClipboard() {
+	constexpr auto large = PhotoSize::Large;
+	if (const auto video = videoContent(large); !video.isEmpty()) {
+		return false;
+	}
+	auto fallback = image(large)->original();
+	if (fallback.isNull()) {
+		return false;
+	}
+	const auto bytes = imageBytes(large);
+	auto mime = std::make_unique<QMimeData>();
+	mime->setImageData(std::move(fallback));
+	if (auto bytes = imageBytes(large); !bytes.isEmpty()) {
+		mime->setData(u"image/jpeg"_q, std::move(bytes));
+	}
+	mime->setData(u"application/x-td-use-jpeg"_q, "1");
+	QGuiApplication::clipboard()->setMimeData(mime.release());
+	return true;
+}
+
 } // namespace Data
