@@ -333,7 +333,7 @@ not_null<Row*> Entry::addToChatList(
 void Entry::removeFromChatList(
 		FilterId filterId,
 		not_null<MainList*> list) {
-	if (!asTopic() && isPinnedDialog(filterId)) {
+	if (isPinnedDialog(filterId)) {
 		owner().setChatPinned(this, filterId, false);
 	}
 
@@ -379,4 +379,8 @@ void Entry::updateChatListEntryPostponed() {
 	});
 }
 
+void Entry::updateChatListEntryHeight() {
+	session().changes().entryUpdated(this, Data::EntryUpdate::Flag::Height);
+}
+
 } // namespace Dialogs
