@@ -11,6 +11,7 @@ class History;
 
 namespace Data {
 class Session;
+class Forum;
 } // namespace Data
 
 namespace Dialogs {
@@ -25,25 +26,28 @@ public:
 
 	// Places on the last place in the list otherwise.
 	// Does nothing if already pinned.
-	void addPinned(const Key &key);
+	void addPinned(Key key);
 
 	// if (pinned) places on the first place in the list.
-	void setPinned(const Key &key, bool pinned);
+	void setPinned(Key key, bool pinned);
 
 	void clear();
 
 	void applyList(
 		not_null<Data::Session*> owner,
 		const QVector<MTPDialogPeer> &list);
+	void applyList(
+		not_null<Data::Forum*> forum,
+		const QVector<MTPint> &list);
 	void applyList(const std::vector<not_null<History*>> &list);
-	void reorder(const Key &key1, const Key &key2);
+	void reorder(Key key1, Key key2);
 
 	const std::vector<Key> &order() const {
 		return _data;
 	}
 
 private:
-	int addPinnedGetPosition(const Key &key);
+	int addPinnedGetPosition(Key key);
 	void applyLimit(int limit);
 
 	FilterId _filterId = 0;
