@@ -580,6 +580,11 @@ QByteArray SerializeMessage(
 	}, [&](const ActionAttachMenuBotAllowed &data) {
 		pushActor();
 		pushAction("attach_menu_bot_allowed");
+	}, [&](const ActionRequestedPeer &data) {
+		pushActor();
+		pushAction("requested_peer");
+		push("button_id", data.buttonId);
+		push("peer_id", data.peerId.value);
 	}, [](v::null_t) {});
 
 	if (v::is_null(message.action.content)) {
