@@ -357,9 +357,9 @@ void SettingsWidget::addFormatAndLocationLabel(
 			st::exportLocationLabel),
 		st::exportLocationPadding);
 	label->overrideLinkClickHandler([=](const QString &url) {
-		if (url == qstr("internal:edit_export_path")) {
+		if (url == u"internal:edit_export_path"_q) {
 			chooseFolder();
-		} else if (url == qstr("internal:edit_format")) {
+		} else if (url == u"internal:edit_format"_q) {
 			chooseFormat();
 		} else {
 			Unexpected("Click handler URL in export limits edit.");
@@ -378,7 +378,7 @@ void SettingsWidget::addLimitsLabel(
 			? rpl::single(langDayOfMonthFull(
 				base::unixtime::parse(from).date()))
 			: tr::lng_export_beginning()
-		) | Ui::Text::ToLink(qsl("internal:edit_from"));
+		) | Ui::Text::ToLink(u"internal:edit_from"_q);
 	}) | rpl::flatten_latest();
 
 	auto tillLink = value() | rpl::map([](const Settings &data) {
@@ -389,7 +389,7 @@ void SettingsWidget::addLimitsLabel(
 			? rpl::single(langDayOfMonthFull(
 				base::unixtime::parse(till).date()))
 			: tr::lng_export_end()
-		) | Ui::Text::ToLink(qsl("internal:edit_till"));
+		) | Ui::Text::ToLink(u"internal:edit_till"_q);
 	}) | rpl::flatten_latest();
 
 	auto datesText = tr::lng_export_limits(
@@ -409,7 +409,7 @@ void SettingsWidget::addLimitsLabel(
 			st::exportLocationLabel),
 		st::exportLimitsPadding);
 	label->overrideLinkClickHandler([=](const QString &url) {
-		if (url == qstr("internal:edit_from")) {
+		if (url == u"internal:edit_from"_q) {
 			const auto done = [=](TimeId limit) {
 				changeData([&](Settings &settings) {
 					settings.singlePeerFrom = limit;
@@ -421,7 +421,7 @@ void SettingsWidget::addLimitsLabel(
 				readData().singlePeerTill,
 				tr::lng_export_from_beginning(),
 				done);
-		} else if (url == qstr("internal:edit_till")) {
+		} else if (url == u"internal:edit_till"_q) {
 			const auto done = [=](TimeId limit) {
 				changeData([&](Settings &settings) {
 					settings.singlePeerTill = limit;
