@@ -652,6 +652,20 @@ const Ui::Text::String &Element::text() const {
 	return _text;
 }
 
+OnlyEmojiAndSpaces Element::isOnlyEmojiAndSpaces() const {
+	if (data()->Has<HistoryMessageTranslation>()) {
+		return OnlyEmojiAndSpaces::No;
+	} else if (!_text.isEmpty()) {
+		return _text.hasNotEmojiAndSpaces()
+			? OnlyEmojiAndSpaces::No
+			: OnlyEmojiAndSpaces::Yes;
+	} else if (data()->originalText().empty()) {
+		return OnlyEmojiAndSpaces::Yes;
+	} else {
+		return OnlyEmojiAndSpaces::Unknown;
+	}
+}
+
 int Element::textHeightFor(int textWidth) {
 	validateText();
 	if (_textWidth != textWidth) {
@@ -837,7 +851,7 @@ void Element::validateText() {
 		};
 		_text.setMarkedText(
 			st::messageTextStyle,
-			item->originalTextWithLocalEntities(),
+			item->translatedTextWithLocalEntities(),
 			Ui::ItemTextOptions(item),
 			context);
 		if (!text.empty() && _text.isEmpty()) {
