@@ -67,6 +67,7 @@ class StickerToast;
 class TopicReopenBar;
 class EmptyPainter;
 class PinnedTracker;
+class TranslateBar;
 
 class RepliesWidget final
 	: public Window::SectionWidget
@@ -170,6 +171,9 @@ public:
 		Painter &p,
 		const Ui::ChatPaintContext &context) override;
 	QString listElementAuthorRank(not_null<const Element*> view) override;
+	History *listTranslateHistory() override;
+	void listAddTranslatedItems(
+		not_null<TranslateTracker*> tracker) override;
 
 	// CornerButtonsDelegate delegate.
 	void cornerButtonsShowAtPosition(
@@ -217,9 +221,9 @@ private:
 	void setTopic(Data::ForumTopic *topic);
 	void setupDragArea();
 	void setupShortcuts();
+	void setupTranslateBar();
 
 	void searchInTopic();
-	void scrollDownAnimationFinish();
 	void updatePinnedVisibility();
 
 	void confirmDeleteSelected();
@@ -278,6 +282,9 @@ private:
 		std::optional<bool> overrideSendImagesAsPhotos,
 		const QString &insertTextOnCancel = QString());
 	bool showSendingFilesError(const Ui::PreparedList &list) const;
+	bool showSendingFilesError(
+		const Ui::PreparedList &list,
+		std::optional<bool> compress) const;
 	void sendingFilesConfirmed(
 		Ui::PreparedList &&list,
 		Ui::SendFilesWay way,
@@ -307,7 +314,6 @@ private:
 	void refreshJoinGroupButton();
 	[[nodiscard]] bool emptyShown() const;
 	[[nodiscard]] bool showSlowmodeError();
-	[[nodiscard]] std::optional<QString> writeRestriction() const;
 
 	const not_null<History*> _history;
 	MsgId _rootId = 0;
@@ -330,16 +336,21 @@ private:
 	bool _skipScrollEvent = false;
 	bool _synteticScrollEvent = false;
 
+	std::unique_ptr<TranslateBar> _translateBar;
+	int _translateBarHeight = 0;
+
 	std::unique_ptr<PinnedTracker> _pinnedTracker;
 	std::unique_ptr<Ui::PinnedBar> _pinnedBar;
 	std::unique_ptr<Ui::PinnedBar> _hidingPinnedBar;
 	int _pinnedBarHeight = 0;
 	FullMsgId _pinnedClickedId;
 	std::optional<FullMsgId> _minPinnedId;
+	HistoryItem *_shownPinnedItem = nullptr;
 
 	std::unique_ptr<Ui::PinnedBar> _rootView;
 	int _rootViewHeight = 0;
 	bool _rootViewInited = false;
+	bool _rootViewInitScheduled = false;
 	rpl::variable<bool> _rootVisible = false;
 
 	std::unique_ptr<Ui::ScrollArea> _scroll;
@@ -365,11 +376,7 @@ public:
 	RepliesMemento(
 		not_null<History*> history,
 		MsgId rootId,
-		MsgId highlightId = 0)
-	: _history(history)
-	, _rootId(rootId)
-	, _highlightId(highlightId) {
-	}
+		MsgId highlightId = 0);
 	explicit RepliesMemento(
 		not_null<HistoryItem*> commentsItem,
 		MsgId commentId = 0);
@@ -408,6 +415,8 @@ public:
 		return _replyReturns;
 	}
 
+	Data::ForumTopic *topicForRemoveRequests() const override;
+
 	[[nodiscard]] not_null<ListMemento*> list() {
 		return &_list;
 	}
