@@ -17,6 +17,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "ui/text/text_utilities.h"
 #include "ui/cached_round_corners.h"
 #include "ui/chat/chat_style.h"
+#include "ui/painter.h"
 #include "core/ui_integration.h"
 #include "data/data_session.h"
 #include "data/data_game.h"
@@ -246,7 +247,17 @@ void Game::draw(Painter &p, const PaintContext &context) const {
 			endskip = _parent->skipBlockWidth();
 		}
 		_parent->prepareCustomEmojiPaint(p, context, _description);
-		_description.drawLeftElided(p, padding.left(), tshift, paintw, width(), _descriptionLines, style::al_left, 0, -1, endskip, false, toDescriptionSelection(context.selection));
+		_description.draw(p, {
+			.position = { padding.left(), tshift },
+			.outerWidth = width(),
+			.availableWidth = paintw,
+			.spoiler = Ui::Text::DefaultSpoilerCache(),
+			.now = context.now,
+			.paused = context.paused,
+			.selection = toDescriptionSelection(context.selection),
+			.elisionLines = _descriptionLines,
+			.elisionRemoveFromEnd = endskip,
+		});
 		tshift += _descriptionLines * lineHeight;
 	}
 	if (_attach) {
@@ -453,7 +464,7 @@ void Game::unloadHeavyPart() {
 	if (_attach) {
 		_attach->unloadHeavyPart();
 	}
-	_description.unloadCustomEmoji();
+	_description.unloadPersistentAnimation();
 }
 
 Game::~Game() {
