@@ -70,14 +70,8 @@ public:
 		return _attach.get();
 	}
 
-	bool hasHeavyPart() const override {
-		return _attach ? _attach->hasHeavyPart() : false;
-	}
-	void unloadHeavyPart() override {
-		if (_attach) {
-			_attach->unloadHeavyPart();
-		}
-	}
+	bool hasHeavyPart() const override;
+	void unloadHeavyPart() override;
 
 private:
 	QSize countOptimalSize() override;
