@@ -13,6 +13,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "history/view/history_view_element.h"
 #include "history/view/history_view_cursor_state.h"
 #include "history/view/media/history_view_media_common.h"
+#include "history/view/media/history_view_media_spoiler.h"
 #include "media/streaming/media_streaming_instance.h"
 #include "media/streaming/media_streaming_player.h"
 #include "media/streaming/media_streaming_document.h"
@@ -20,6 +21,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "main/main_session.h"
 #include "main/main_session_settings.h"
 #include "ui/image/image.h"
+#include "ui/effects/spoiler_mess.h"
 #include "ui/chat/chat_style.h"
 #include "ui/grouped_layout.h"
 #include "ui/cached_round_corners.h"
@@ -58,10 +60,12 @@ Photo::Streamed::Streamed(
 Photo::Photo(
 	not_null<Element*> parent,
 	not_null<HistoryItem*> realParent,
-	not_null<PhotoData*> photo)
+	not_null<PhotoData*> photo,
+	bool spoiler)
 : File(parent, realParent)
 , _data(photo)
-, _caption(st::minPhotoSize - st::msgPadding.left() - st::msgPadding.right()) {
+, _caption(st::minPhotoSize - st::msgPadding.left() - st::msgPadding.right())
+, _spoiler(spoiler ? std::make_unique<MediaSpoiler>() : nullptr) {
 	_caption = createCaption(realParent);
 	create(realParent->fullId());
 }
@@ -110,6 +114,9 @@ void Photo::create(FullMsgId contextId, PeerData *chat) {
 			|| _data->hasExact(PhotoSize::Thumbnail))) {
 		_data->load(PhotoSize::Small, contextId);
 	}
+	if (_spoiler) {
+		createSpoilerLink(_spoiler.get());
+	}
 }
 
 void Photo::ensureDataMediaCreated() const {
@@ -132,12 +139,16 @@ void Photo::dataMediaCreated() const {
 }
 
 bool Photo::hasHeavyPart() const {
-	return _streamed || _dataMedia;
+	return (_spoiler && _spoiler->animation) || _streamed || _dataMedia;
 }
 
 void Photo::unloadHeavyPart() {
 	stopAnimation();
 	_dataMedia = nullptr;
+	if (_spoiler) {
+		_spoiler->background = _spoiler->cornerCache = QImage();
+		_spoiler->animation = nullptr;
+	}
 	_imageCache = QImage();
 	_caption.unloadPersistentAnimation();
 }
@@ -276,8 +287,22 @@ void Photo::draw(Painter &p, const PaintContext &context) const {
 			Assert(rounding.has_value());
 			fillImageShadow(p, rthumb, *rounding, context);
 		}
-		validateImageCache(rthumb.size(), rounding);
-		p.drawImage(rthumb.topLeft(), _imageCache);
+		const auto revealed = _spoiler
+			? _spoiler->revealAnimation.value(_spoiler->revealed ? 1. : 0.)
+			: 1.;
+		if (revealed < 1.) {
+			validateSpoilerImageCache(rthumb.size(), rounding);
+		}
+		if (revealed > 0.) {
+			validateImageCache(rthumb.size(), rounding);
+			p.drawImage(rthumb.topLeft(), _imageCache);
+		}
+		if (revealed < 1.) {
+			p.setOpacity(1. - revealed);
+			p.drawImage(rthumb.topLeft(), _spoiler->background);
+			fillImageSpoiler(p, _spoiler.get(), rthumb, context);
+			p.setOpacity(1.);
+		}
 		if (context.selected()) {
 			fillImageOverlay(p, rthumb, rounding, context);
 		}
@@ -414,9 +439,30 @@ void Photo::validateImageCache(
 	_imageCacheBlurred = blurredValue;
 }
 
+void Photo::validateSpoilerImageCache(
+		QSize outer,
+		std::optional<Ui::BubbleRounding> rounding) const {
+	Expects(_spoiler != nullptr);
+
+	const auto ratio = style::DevicePixelRatio();
+	if (_spoiler->background.size() == (outer * ratio)
+		&& _spoiler->backgroundRounding == rounding) {
+		return;
+	}
+	_spoiler->background = Images::Round(
+		prepareImageCacheWithLarge(outer, nullptr),
+		MediaRoundingMask(rounding));
+	_spoiler->backgroundRounding = rounding;
+}
+
 QImage Photo::prepareImageCache(QSize outer) const {
+	return prepareImageCacheWithLarge(
+		outer,
+		_dataMedia->image(PhotoSize::Large));
+}
+
+QImage Photo::prepareImageCacheWithLarge(QSize outer, Image *large) const {
 	using Size = PhotoSize;
-	const auto large = _dataMedia->image(Size::Large);
 	auto blurred = (Image*)nullptr;
 	if (const auto embedded = _dataMedia->thumbnailInline()) {
 		blurred = embedded;
@@ -435,9 +481,10 @@ QImage Photo::prepareImageCache(QSize outer) const {
 
 void Photo::paintUserpicFrame(
 		Painter &p,
-		const PaintContext &context,
-		QPoint photoPosition) const {
-	const auto autoplay = _data->videoCanBePlayed() && videoAutoplayEnabled();
+		QPoint photoPosition,
+		bool markFrameShown) const {
+	const auto autoplay = _data->videoCanBePlayed()
+		&& videoAutoplayEnabled();
 	const auto startPlay = autoplay && !_streamed;
 	if (startPlay) {
 		const_cast<Photo*>(this)->playAnimation(true);
@@ -447,8 +494,6 @@ void Photo::paintUserpicFrame(
 
 	const auto size = QSize(width(), height());
 	const auto rect = QRect(photoPosition, size);
-	const auto st = context.st;
-	const auto sti = context.imageStyle();
 	const auto forum = _parent->data()->history()->isForum();
 
 	if (_streamed
@@ -481,7 +526,7 @@ void Photo::paintUserpicFrame(
 		} else {
 			_streamed->frozenFrame = QImage();
 			p.drawImage(rect, _streamed->instance.frame(request));
-			if (!context.paused) {
+			if (markFrameShown) {
 				_streamed->instance.markFrameShown();
 			}
 		}
@@ -489,10 +534,23 @@ void Photo::paintUserpicFrame(
 	}
 	validateUserpicImageCache(size, forum);
 	p.drawImage(rect, _imageCache);
+}
+
+void Photo::paintUserpicFrame(
+		Painter &p,
+		const PaintContext &context,
+		QPoint photoPosition) const {
+	paintUserpicFrame(p, photoPosition, !context.paused);
 
 	if (_data->videoCanBePlayed() && !_streamed) {
+		const auto st = context.st;
+		const auto sti = context.imageStyle();
 		const auto innerSize = st::msgFileLayout.thumbSize;
-		auto inner = QRect(rect.x() + (rect.width() - innerSize) / 2, rect.y() + (rect.height() - innerSize) / 2, innerSize, innerSize);
+		auto inner = QRect(
+			photoPosition.x() + (width() - innerSize) / 2,
+			photoPosition.y() + (height() - innerSize) / 2,
+			innerSize,
+			innerSize);
 		p.setPen(Qt::NoPen);
 		if (context.selected()) {
 			p.setBrush(st->msgDateImgBgSelected());
@@ -536,15 +594,15 @@ TextState Photo::textState(QPoint point, StateRequest request) const {
 	}
 	if (QRect(paintx, painty, paintw, painth).contains(point)) {
 		ensureDataMediaCreated();
-		if (_data->uploading()) {
-			result.link = _cancell;
-		} else if (_dataMedia->loaded()) {
-			result.link = _openl;
-		} else if (_data->loading()) {
-			result.link = _cancell;
-		} else {
-			result.link = _savel;
-		}
+		result.link = (_spoiler && !_spoiler->revealed)
+			? _spoiler->link
+			: _data->uploading()
+			? _cancell
+			: _dataMedia->loaded()
+			? _openl
+			: _data->loading()
+			? _cancell
+			: _savel;
 	}
 	if (_caption.isEmpty() && _parent->media() == this) {
 		auto fullRight = paintx + paintw;
@@ -593,8 +651,6 @@ void Photo::drawGrouped(
 	ensureDataMediaCreated();
 	_dataMedia->automaticLoad(_realParent->fullId(), _parent->data());
 
-	validateGroupedCache(geometry, rounding, cacheKey, cache);
-
 	const auto st = context.st;
 	const auto sti = context.imageStyle();
 	const auto loaded = _dataMedia->loaded();
@@ -608,7 +664,22 @@ void Photo::drawGrouped(
 	}
 	const auto radial = isRadialAnimation();
 
-	p.drawPixmap(geometry.topLeft(), *cache);
+	const auto revealed = _spoiler
+		? _spoiler->revealAnimation.value(_spoiler->revealed ? 1. : 0.)
+		: 1.;
+	if (revealed < 1.) {
+		validateSpoilerImageCache(geometry.size(), rounding);
+	}
+	if (revealed > 0.) {
+		validateGroupedCache(geometry, rounding, cacheKey, cache);
+		p.drawPixmap(geometry.topLeft(), *cache);
+	}
+	if (revealed < 1.) {
+		p.setOpacity(1. - revealed);
+		p.drawImage(geometry.topLeft(), _spoiler->background);
+		fillImageSpoiler(p, _spoiler.get(), geometry, context);
+		p.setOpacity(1.);
+	}
 
 	const auto overlayOpacity = context.selected()
 		? (1. - highlightOpacity)
@@ -688,7 +759,9 @@ TextState Photo::getStateGrouped(
 		return {};
 	}
 	ensureDataMediaCreated();
-	return TextState(_parent, _data->uploading()
+	return TextState(_parent, (_spoiler && !_spoiler->revealed)
+		? _spoiler->link
+		: _data->uploading()
 		? _cancell
 		: _dataMedia->loaded()
 		? _openl
@@ -904,6 +977,13 @@ TextForMimeData Photo::selectedText(TextSelection selection) const {
 	return _caption.toTextForMimeData(selection);
 }
 
+void Photo::hideSpoilers() {
+	_caption.setSpoilerRevealed(false, anim::type::instant);
+	if (_spoiler) {
+		_spoiler->revealed = false;
+	}
+}
+
 bool Photo::needsBubble() const {
 	if (!_caption.isEmpty()) {
 		return true;
