@@ -9,6 +9,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 
 #include "history/view/media/history_view_file.h"
 
+class Image;
 enum class ImageRoundRadius;
 
 namespace Data {
@@ -31,7 +32,8 @@ public:
 	Photo(
 		not_null<Element*> parent,
 		not_null<HistoryItem*> realParent,
-		not_null<PhotoData*> photo);
+		not_null<PhotoData*> photo,
+		bool spoiler);
 	Photo(
 		not_null<Element*> parent,
 		not_null<PeerData*> chat,
@@ -59,6 +61,12 @@ public:
 	PhotoData *getPhoto() const override {
 		return _data;
 	}
+	void showPhoto(FullMsgId id);
+
+	void paintUserpicFrame(
+		Painter &p,
+		QPoint photoPosition,
+		bool markFrameShown) const;
 
 	QSize sizeForGroupingOptimal(int maxWidth) const override;
 	QSize sizeForGrouping(int width) const override;
@@ -80,6 +88,7 @@ public:
 	TextWithEntities getCaption() const override {
 		return _caption.toTextWithEntities();
 	}
+	void hideSpoilers() override;
 	bool needsBubble() const override;
 	bool customInfoLayout() const override {
 		return _caption.isEmpty();
@@ -103,8 +112,6 @@ protected:
 private:
 	struct Streamed;
 
-	void showPhoto(FullMsgId id);
-
 	void create(FullMsgId contextId, PeerData *chat = nullptr);
 
 	void playAnimation(bool autoplay) override;
@@ -131,6 +138,12 @@ private:
 		std::optional<Ui::BubbleRounding> rounding) const;
 	void validateUserpicImageCache(QSize size, bool forum) const;
 	[[nodiscard]] QImage prepareImageCache(QSize outer) const;
+	void validateSpoilerImageCache(
+		QSize outer,
+		std::optional<Ui::BubbleRounding> rounding) const;
+	[[nodiscard]] QImage prepareImageCacheWithLarge(
+		QSize outer,
+		Image *large) const;
 
 	bool videoAutoplayEnabled() const;
 	void setStreamed(std::unique_ptr<Streamed> value);
@@ -149,6 +162,7 @@ private:
 	Ui::Text::String _caption;
 	mutable std::shared_ptr<Data::PhotoMedia> _dataMedia;
 	mutable std::unique_ptr<Streamed> _streamed;
+	const std::unique_ptr<MediaSpoiler> _spoiler;
 	mutable QImage _imageCache;
 	mutable std::optional<Ui::BubbleRounding> _imageCacheRounding;
 	int _serviceWidth : 30 = 0;
