@@ -247,7 +247,7 @@ int Selector::extendTopForCategories() const {
 int Selector::minimalHeight() const {
 	return _skipy
 		+ (_recentRows * _size)
-		+ st::roundRadiusSmall
+		+ st::emojiPanRadius
 		+ st::reactPanelEmojiPan.padding.bottom();
 }
 
@@ -282,6 +282,12 @@ void Selector::initGeometry(int innerTop) {
 	}
 }
 
+void Selector::beforeDestroy() {
+	if (_list) {
+		_list->beforeHiding();
+	}
+}
+
 void Selector::updateShowState(
 		float64 progress,
 		float64 opacity,
@@ -431,7 +437,7 @@ auto Selector::paintExpandingBg(QPainter &p, float64 progress)
 	constexpr auto kFramesCount = Ui::RoundAreaWithShadow::kFramesCount;
 	const auto frame = int(base::SafeRound(progress * (kFramesCount - 1)));
 	const auto radiusStart = st::reactStripHeight / 2.;
-	const auto radiusEnd = st::roundRadiusSmall;
+	const auto radiusEnd = st::emojiPanRadius;
 	const auto radius = _reactions.customAllowed
 		? (radiusStart + progress * (radiusEnd - radiusStart))
 		: radiusStart;
@@ -521,7 +527,7 @@ void Selector::finishExpand() {
 		const auto pattern = _cachedRound.validateFrame(
 			kFramesCount - 1,
 			1.,
-			st::roundRadiusSmall);
+			st::emojiPanRadius);
 		const auto fill = _cachedRound.FillWithImage(q, rect(), pattern);
 		if (!fill.isEmpty()) {
 			q.fillRect(fill, st::defaultPopupMenu.menu.itemBg);
@@ -531,6 +537,7 @@ void Selector::finishExpand() {
 		_footer->show();
 	}
 	_scroll->show();
+	_list->afterShown();
 
 	if (const auto controller = _parentController.get()) {
 		controller->session().api().updateCustomEmoji();
@@ -677,6 +684,7 @@ void Selector::expand() {
 	cacheExpandIcon();
 
 	[[maybe_unused]] const auto grabbed = Ui::GrabWidget(_scroll);
+	_list->prepareExpanding();
 	setSelected(-1);
 
 	base::call_delayed(kExpandDelay, this, [this] {
@@ -939,6 +947,12 @@ AttachSelectorResult MakeJustSelectorMenu(
 	}
 	const auto selectorInnerTop = menu->preparedPadding().top()
 		- st::reactStripExtend.top();
+	menu->animatePhaseValue(
+	) | rpl::start_with_next([=](Ui::PopupMenu::AnimatePhase phase) {
+		if (phase == Ui::PopupMenu::AnimatePhase::StartHide) {
+			selector->beforeDestroy();
+		}
+	}, selector->lifetime());
 	selector->initGeometry(selectorInnerTop);
 	selector->show();
 
@@ -1004,6 +1018,12 @@ AttachSelectorResult AttachSelectorToMenu(
 	const auto selectorInnerTop = selector->useTransparency()
 		? (menu->preparedPadding().top() - st::reactStripExtend.top())
 		: st::lineWidth;
+	menu->animatePhaseValue(
+	) | rpl::start_with_next([=](Ui::PopupMenu::AnimatePhase phase) {
+		if (phase == Ui::PopupMenu::AnimatePhase::StartHide) {
+			selector->beforeDestroy();
+		}
+	}, selector->lifetime());
 	selector->initGeometry(selectorInnerTop);
 	selector->show();
 
