@@ -7,8 +7,6 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 */
 #include "info/info_controller.h"
 
-#include <rpl/range.h>
-#include <rpl/then.h>
 #include "ui/search_field_controller.h"
 #include "data/data_shared_media.h"
 #include "info/info_content_widget.h"
@@ -19,11 +17,12 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "data/data_peer.h"
 #include "data/data_channel.h"
 #include "data/data_chat.h"
+#include "data/data_forum_topic.h"
+#include "data/data_forum.h"
 #include "data/data_session.h"
 #include "data/data_media_types.h"
 #include "data/data_download_manager.h"
 #include "history/history_item.h"
-#include "history/history.h"
 #include "main/main_session.h"
 #include "window/window_session_controller.h"
 
@@ -32,6 +31,9 @@ namespace Info {
 Key::Key(not_null<PeerData*> peer) : _value(peer) {
 }
 
+Key::Key(not_null<Data::ForumTopic*> topic) : _value(topic) {
+}
+
 Key::Key(Settings::Tag settings) : _value(settings) {
 }
 
@@ -45,6 +47,16 @@ Key::Key(not_null<PollData*> poll, FullMsgId contextId)
 PeerData *Key::peer() const {
 	if (const auto peer = std::get_if<not_null<PeerData*>>(&_value)) {
 		return *peer;
+	} else if (const auto topic = this->topic()) {
+		return topic->channel();
+	}
+	return nullptr;
+}
+
+Data::ForumTopic *Key::topic() const {
+	if (const auto topic = std::get_if<not_null<Data::ForumTopic*>>(
+			&_value)) {
+		return *topic;
 	}
 	return nullptr;
 }
@@ -88,15 +100,21 @@ rpl::producer<SparseIdsMergedSlice> AbstractController::mediaSource(
 		return false;
 	}();
 
-	auto mediaViewer = isScheduled
+	const auto mediaViewer = isScheduled
 		? SharedScheduledMediaViewer
 		: SharedMediaMergedViewer;
+	const auto topicId = isScheduled
+		? SparseIdsMergedSlice::kScheduledTopicId
+		: topic()
+		? topic()->rootId()
+		: MsgId(0);
 
 	return mediaViewer(
 		&session(),
 		SharedMediaMergedKey(
 			SparseIdsMergedSlice::Key(
 				peer()->id,
+				topicId,
 				migratedPeerId(),
 				aroundId),
 			section().mediaType()),
@@ -169,11 +187,15 @@ Controller::Controller(
 , _section(memento->section()) {
 	updateSearchControllers(memento);
 	setupMigrationViewer();
+	setupTopicViewer();
 }
 
 void Controller::setupMigrationViewer() {
 	const auto peer = _key.peer();
-	if (!peer || (!peer->isChat() && !peer->isChannel()) || _migrated) {
+	if (_key.topic()
+		|| !peer
+		|| (!peer->isChat() && !peer->isChannel())
+		|| _migrated) {
 		return;
 	}
 	peer->session().changes().peerFlagsValue(
@@ -182,23 +204,39 @@ void Controller::setupMigrationViewer() {
 	) | rpl::filter([=] {
 		return peer->migrateTo() || (peer->migrateFrom() != _migrated);
 	}) | rpl::start_with_next([=] {
-		const auto window = parentController();
-		const auto section = _section;
-		auto params = Window::SectionShow(
-			Window::SectionShow::Way::Backward,
-			anim::type::instant,
-			anim::activation::background);
-		if (wrap() == Wrap::Side) {
-			params.thirdColumn = true;
-		}
-		InvokeQueued(_widget, [=] {
-			window->showSection(
-				std::make_shared<Memento>(peer, section),
-				params);
-		});
+		replaceWith(std::make_shared<Memento>(peer, _section));
 	}, lifetime());
 }
 
+void Controller::replaceWith(std::shared_ptr<Memento> memento) {
+	const auto window = parentController();
+	auto params = Window::SectionShow(
+		Window::SectionShow::Way::Backward,
+		anim::type::instant,
+		anim::activation::background);
+	if (wrap() == Wrap::Side) {
+		params.thirdColumn = true;
+	}
+	InvokeQueued(_widget, [=, memento = std::move(memento)]() mutable {
+		window->showSection(std::move(memento), params);
+	});
+}
+
+void Controller::setupTopicViewer() {
+	session().data().itemIdChanged(
+	) | rpl::start_with_next([=](const Data::Session::IdChange &change) {
+		if (const auto topic = _key.topic()) {
+			if (topic->rootId() == change.oldId
+				|| (topic->peer()->id == change.newId.peer
+					&& topic->rootId() == change.newId.msg)) {
+				const auto now = topic->forum()->topicFor(change.newId.msg);
+				_key = Key(now);
+				replaceWith(std::make_shared<Memento>(now, _section));
+			}
+		}
+	}, _lifetime);
+}
+
 Wrap Controller::wrap() const {
 	return _widget->wrap();
 }
@@ -305,6 +343,7 @@ auto Controller::produceSearchQuery(
 	auto result = SearchQuery();
 	result.type = _section.mediaType();
 	result.peerId = _key.peer()->id;
+	result.topicRootId = _key.topic() ? _key.topic()->rootId() : 0;
 	result.query = query;
 	result.migratedPeerId = _migrated ? _migrated->id : PeerId(0);
 	return result;
@@ -339,6 +378,7 @@ rpl::producer<SparseIdsMergedSlice> Controller::mediaSource(
 		SharedMediaMergedKey(
 			SparseIdsMergedSlice::Key(
 				query.peerId,
+				query.topicRootId,
 				query.migratedPeerId,
 				aroundId),
 			query.type),
