@@ -15,6 +15,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "lang/lang_keys.h"
 #include "history/history.h"
 #include "history/history_item.h"
+#include "history/history_item_helpers.h"
 #include "data/data_session.h"
 #include "data/data_chat.h"
 #include "data/data_channel.h"
@@ -415,18 +416,24 @@ std::unique_ptr<BaseLayout> Provider::createLayout(
 		return nullptr;
 	};
 	const auto getFile = [&]() -> DocumentData* {
-		if (auto media = item->media()) {
+		if (const auto media = item->media()) {
 			return media->document();
 		}
 		return nullptr;
 	};
+	const auto spoiler = [&] {
+		if (const auto media = item->media()) {
+			return media->hasSpoiler();
+		}
+		return false;
+	};
 
 	const auto &songSt = st::overviewFileLayout;
 	using namespace Overview::Layout;
 	switch (type) {
 	case Type::Photo:
 		if (const auto photo = getPhoto()) {
-			return std::make_unique<Photo>(delegate, item, photo);
+			return std::make_unique<Photo>(delegate, item, photo, spoiler());
 		}
 		return nullptr;
 	case Type::GIF:
@@ -436,7 +443,7 @@ std::unique_ptr<BaseLayout> Provider::createLayout(
 		return nullptr;
 	case Type::Video:
 		if (const auto file = getFile()) {
-			return std::make_unique<Video>(delegate, item, file);
+			return std::make_unique<Video>(delegate, item, file, spoiler());
 		}
 		return nullptr;
 	case Type::File:
