@@ -87,6 +87,10 @@ rpl::producer<int> Members::onlineCountValue() const {
 	return _listController->onlineCountValue();
 }
 
+rpl::producer<int> Members::fullCountValue() const {
+	return _listController->fullCountValue();
+}
+
 rpl::producer<Ui::ScrollToRequest> Members::scrollToRequests() const {
 	return _scrollToRequests.events();
 }
@@ -162,13 +166,18 @@ void Members::setupHeader() {
 }
 
 object_ptr<Ui::FlatLabel> Members::setupTitle() {
+	auto visible = _peer->isMegagroup()
+		? CanViewParticipantsValue(_peer->asMegagroup())
+		: rpl::single(true);
 	auto result = object_ptr<Ui::FlatLabel>(
 		_titleWrap,
-		tr::lng_chat_status_members(
-			lt_count_decimal,
-			MembersCountValue(_peer) | tr::to_count(),
-			Ui::Text::Upper
-		),
+		rpl::conditional(
+			std::move(visible),
+			tr::lng_chat_status_members(
+				lt_count_decimal,
+				MembersCountValue(_peer) | tr::to_count(),
+				Ui::Text::Upper),
+			tr::lng_channel_admins(Ui::Text::Upper)),
 		st::infoBlockHeaderLabel);
 	result->setAttribute(Qt::WA_TransparentForMouseEvents);
 	return result;
@@ -184,8 +193,16 @@ void Members::setupButtons() {
 	//_searchField->hide();
 	//_cancelSearch->setVisible(false);
 
-	auto addMemberShown = CanAddMemberValue(_peer)
-		| rpl::start_spawning(lifetime());
+	auto visible = _peer->isMegagroup()
+		? CanViewParticipantsValue(_peer->asMegagroup())
+		: rpl::single(true);
+	rpl::duplicate(visible) | rpl::start_with_next([=](bool visible) {
+		_openMembers->setVisible(visible);
+	}, lifetime());
+
+	auto addMemberShown = CanAddMemberValue(
+		_peer
+	) | rpl::start_spawning(lifetime());
 	_addMember->showOn(rpl::duplicate(addMemberShown));
 	_addMember->addClickHandler([this] { // TODO throttle(ripple duration)
 		this->addMember();
@@ -205,7 +222,8 @@ void Members::setupButtons() {
 
 	rpl::combine(
 		std::move(addMemberShown),
-		std::move(searchShown)
+		std::move(searchShown),
+		std::move(visible)
 	) | rpl::start_with_next([this] {
 		updateHeaderControlsGeometry(width());
 	}, lifetime());
