@@ -9,6 +9,8 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 
 #include "history/history_location_manager.h"
 
+struct HistoryMessageMarkupData;
+
 namespace Main {
 class Session;
 } // namespace Main
@@ -48,7 +50,7 @@ public:
 		UserId viaBotId,
 		MsgId replyToId,
 		const QString &postAuthor,
-		const MTPReplyMarkup &markup) const = 0;
+		HistoryMessageMarkupData &&markup) const = 0;
 	virtual QString getErrorOnSend(
 		const Result *owner,
 		not_null<History*> history) const = 0;
@@ -90,7 +92,7 @@ public:
 		UserId viaBotId,
 		MsgId replyToId,
 		const QString &postAuthor,
-		const MTPReplyMarkup &markup) const override;
+		HistoryMessageMarkupData &&markup) const override;
 
 	QString getErrorOnSend(
 		const Result *owner,
@@ -258,7 +260,7 @@ public:
 		UserId viaBotId,
 		MsgId replyToId,
 		const QString &postAuthor,
-		const MTPReplyMarkup &markup) const override;
+		HistoryMessageMarkupData &&markup) const override;
 
 	QString getErrorOnSend(
 		const Result *owner,
@@ -299,7 +301,7 @@ public:
 		UserId viaBotId,
 		MsgId replyToId,
 		const QString &postAuthor,
-		const MTPReplyMarkup &markup) const override;
+		HistoryMessageMarkupData &&markup) const override;
 
 	QString getErrorOnSend(
 		const Result *owner,
@@ -334,7 +336,7 @@ public:
 		UserId viaBotId,
 		MsgId replyToId,
 		const QString &postAuthor,
-		const MTPReplyMarkup &markup) const override;
+		HistoryMessageMarkupData &&markup) const override;
 
 	QString getErrorOnSend(
 		const Result *owner,
