@@ -443,13 +443,10 @@ void Inner::clearInlineRowsPanel() {
 }
 
 void Inner::refreshMosaicOffset() {
-	const auto top = st::stickerPanPadding
-		+ (_switchPmButton
-			? _switchPmButton->height() + st::inlineResultsSkip
-			: 0);
-	_mosaic.setOffset(
-		st::inlineResultsLeft - st::roundRadiusSmall,
-		top);
+	const auto top = _switchPmButton
+		? (_switchPmButton->height() + st::inlineResultsSkip)
+		: 0;
+	_mosaic.setPadding(st::gifsPadding + QMargins(0, top, 0, 0));
 }
 
 void Inner::refreshSwitchPmButton(const CacheEntry *entry) {
