@@ -19,10 +19,6 @@ class Widget;
 enum class EnterPoint : uchar;
 } // namespace Intro
 
-namespace Media {
-class SystemMediaControlsManager;
-} // namespace Media
-
 namespace Window {
 class MediaPreviewWidget;
 class SectionMemento;
@@ -42,6 +38,8 @@ class LayerStackWidget;
 
 class MediaPreviewWidget;
 
+extern const char kOptionAutoScrollInactiveChat[];
+
 class MainWindow : public Platform::MainWindow {
 public:
 	explicit MainWindow(not_null<Window::Controller*> controller);
@@ -134,8 +132,6 @@ private:
 
 	void themeUpdated(const Window::Theme::BackgroundUpdate &data);
 
-	std::unique_ptr<Media::SystemMediaControlsManager> _mediaControlsManager;
-
 	QPoint _lastMousePosition;
 
 	object_ptr<Window::PasscodeLockWidget> _passcodeLock = { nullptr };
