@@ -8,15 +8,17 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #pragma once
 
 #include "ui/effects/animation_value.h"
-#include "ui/chat/attach/attach_prepare.h"
 #include "core/file_location.h"
 #include "data/data_audio_msg_id.h"
 #include "base/bytes.h"
-#include "base/observer.h"
 #include "base/timer.h"
 
 #include <QtCore/QTimer>
 
+namespace Ui {
+struct PreparedFileInformation;
+} // namespace Ui
+
 namespace Media {
 struct ExternalSoundData;
 struct ExternalSoundPart;
@@ -60,7 +62,7 @@ constexpr auto kWaveformSamplesCount = 100;
 class Fader;
 class Loaders;
 
-base::Observable<AudioMsgId> &Updated();
+[[nodiscard]] rpl::producer<AudioMsgId> Updated();
 
 float64 ComputeVolume(AudioMsgId::Type type);
 
@@ -370,7 +372,7 @@ private:
 
 };
 
-[[nodiscard]] Ui::PreparedFileInformation::Song PrepareForSending(
+[[nodiscard]] Ui::PreparedFileInformation PrepareForSending(
 	const QString &fname,
 	const QByteArray &data);
 
