@@ -14,14 +14,12 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "data/data_document.h"
 #include "data/data_document_media.h"
 #include "data/data_file_origin.h"
-#include "mainwidget.h"
 #include "main/main_account.h"
 #include "main/main_session.h"
 #include "media/audio/media_audio.h"
 #include "media/streaming/media_streaming_instance.h"
 #include "media/streaming/media_streaming_player.h"
 #include "ui/text/format_song_document_name.h"
-#include "window/window_controller.h"
 
 #include <ksandbox.h>
 
@@ -45,8 +43,7 @@ bool SystemMediaControlsManager::Supported() {
 	return base::Platform::SystemMediaControls::Supported();
 }
 
-SystemMediaControlsManager::SystemMediaControlsManager(
-	not_null<Window::Controller*> controller)
+SystemMediaControlsManager::SystemMediaControlsManager()
 : _controls(std::make_unique<base::Platform::SystemMediaControls>()) {
 
 	using PlaybackStatus =
@@ -58,7 +55,7 @@ SystemMediaControlsManager::SystemMediaControlsManager(
 		_controls->setServiceName(u"tdesktop"_q);
 	}
 	_controls->setApplicationName(AppName.utf16());
-	const auto inited = _controls->init(controller->widget());
+	const auto inited = _controls->init();
 	if (!inited) {
 		LOG(("SystemMediaControlsManager failed to init."));
 		return;
@@ -227,7 +224,7 @@ SystemMediaControlsManager::SystemMediaControlsManager(
 		case Command::Next: mediaPlayer->next(type); break;
 		case Command::Previous: mediaPlayer->previous(type); break;
 		case Command::Stop: mediaPlayer->stop(type); break;
-		case Command::Raise: controller->widget()->showFromTray(); break;
+		case Command::Raise: Core::App().activate(); break;
 		case Command::LoopNone: {
 			Core::App().settings().setPlayerRepeatMode(RepeatMode::None);
 			Core::App().saveSettingsDelayed();
@@ -252,9 +249,7 @@ SystemMediaControlsManager::SystemMediaControlsManager(
 			break;
 		}
 		case Command::Quit: {
-			if (const auto main = controller->widget()->sessionContent()) {
-				main->closeBothPlayers();
-			}
+			Media::Player::instance()->stopAndClose();
 			break;
 		}
 		}
