@@ -28,10 +28,12 @@ public:
 	OpenRequest(
 		Window::SessionController *controller,
 		not_null<PhotoData*> photo,
-		HistoryItem *item)
+		HistoryItem *item,
+		MsgId topicRootId)
 	: _controller(controller)
 	, _photo(photo)
-	, _item(item) {
+	, _item(item)
+	, _topicRootId(topicRootId) {
 	}
 	OpenRequest(
 		Window::SessionController *controller,
@@ -46,11 +48,13 @@ public:
 		Window::SessionController *controller,
 		not_null<DocumentData*> document,
 		HistoryItem *item,
+		MsgId topicRootId,
 		bool continueStreaming = false,
 		crl::time startTime = 0)
 	: _controller(controller)
 	, _document(document)
 	, _item(item)
+	, _topicRootId(topicRootId)
 	, _continueStreaming(continueStreaming)
 	, _startTime(startTime) {
 	}
@@ -63,35 +67,39 @@ public:
 	, _cloudTheme(cloudTheme) {
 	}
 
-	PeerData *peer() const {
+	[[nodiscard]] PeerData *peer() const {
 		return _peer;
 	}
 
-	PhotoData *photo() const {
+	[[nodiscard]] PhotoData *photo() const {
 		return _photo;
 	}
 
-	HistoryItem *item() const {
+	[[nodiscard]] HistoryItem *item() const {
 		return _item;
 	}
 
-	DocumentData *document() const {
+	[[nodiscard]] MsgId topicRootId() const {
+		return _topicRootId;
+	}
+
+	[[nodiscard]] DocumentData *document() const {
 		return _document;
 	}
 
-	std::optional<Data::CloudTheme> cloudTheme() const {
+	[[nodiscard]] std::optional<Data::CloudTheme> cloudTheme() const {
 		return _cloudTheme;
 	}
 
-	Window::SessionController *controller() const {
+	[[nodiscard]] Window::SessionController *controller() const {
 		return _controller;
 	}
 
-	bool continueStreaming() const {
+	[[nodiscard]] bool continueStreaming() const {
 		return _continueStreaming;
 	}
 
-	crl::time startTime() const {
+	[[nodiscard]] crl::time startTime() const {
 		return _startTime;
 	}
 
@@ -101,6 +109,7 @@ private:
 	PhotoData *_photo = nullptr;
 	PeerData *_peer = nullptr;
 	HistoryItem *_item = nullptr;
+	MsgId _topicRootId = 0;
 	std::optional<Data::CloudTheme> _cloudTheme = std::nullopt;
 	bool _continueStreaming = false;
 	crl::time _startTime = 0;
