@@ -917,12 +917,6 @@ void Panel::showWebviewError(
 	case Error::NoGtkOrWebkit2Gtk:
 		rich.append(tr::lng_payments_webview_install_webkit(tr::now));
 		break;
-	case Error::MutterWM:
-		rich.append(tr::lng_payments_webview_switch_mutter(tr::now));
-		break;
-	case Error::Wayland:
-		rich.append(tr::lng_payments_webview_switch_wayland(tr::now));
-		break;
 	case Error::OldWindows:
 		rich.append(tr::lng_payments_webview_update_windows(tr::now));
 		break;
