@@ -14,13 +14,8 @@ class WaylandIntegration {
 public:
 	[[nodiscard]] static WaylandIntegration *Instance();
 
-	[[nodiscard]] QString nativeHandle(QWindow *window);
 	[[nodiscard]] bool skipTaskbarSupported();
 	void skipTaskbar(QWindow *window, bool skip);
-	void registerAppMenu(
-		QWindow *window,
-		const QString &serviceName,
-		const QString &objectPath);
 
 private:
 	WaylandIntegration();
