@@ -26,10 +26,6 @@ WaylandIntegration *WaylandIntegration::Instance() {
 	return &instance;
 }
 
-QString WaylandIntegration::nativeHandle(QWindow *window) {
-	return {};
-}
-
 bool WaylandIntegration::skipTaskbarSupported() {
 	return false;
 }
@@ -37,11 +33,5 @@ bool WaylandIntegration::skipTaskbarSupported() {
 void WaylandIntegration::skipTaskbar(QWindow *window, bool skip) {
 }
 
-void WaylandIntegration::registerAppMenu(
-		QWindow *window,
-		const QString &serviceName,
-		const QString &objectPath) {
-}
-
 } // namespace internal
 } // namespace Platform
