@@ -32,7 +32,7 @@ constexpr auto kPropertiesInterface = "org.freedesktop.DBus.Properties"_cs;
 bool ShowXDPOpenWithDialog(const QString &filepath) {
 	try {
 		const auto connection = Gio::DBus::Connection::get_sync(
-			Gio::DBus::BusType::BUS_TYPE_SESSION);
+			Gio::DBus::BusType::SESSION);
 
 		auto reply = connection->call_sync(
 			std::string(base::Platform::XDP::kObjectPath),
@@ -122,8 +122,6 @@ bool ShowXDPOpenWithDialog(const QString &filepath) {
 			}
 		});
 
-		const auto fdList = Gio::UnixFDList::create();
-		fdList->append(fd);
 		auto outFdList = Glib::RefPtr<Gio::UnixFDList>();
 
 		connection->call_sync(
@@ -132,7 +130,7 @@ bool ShowXDPOpenWithDialog(const QString &filepath) {
 			"OpenFile",
 			Glib::VariantContainerBase::create_tuple({
 				Glib::Variant<Glib::ustring>::create(parentWindowId),
-				Glib::wrap(g_variant_new_handle(0)),
+				Glib::Variant<int>::create_handle(0),
 				Glib::Variant<std::map<
 					Glib::ustring,
 					Glib::VariantBase
@@ -151,7 +149,7 @@ bool ShowXDPOpenWithDialog(const QString &filepath) {
 					},
 				}),
 			}),
-			fdList,
+			Gio::UnixFDList::create(std::vector<int>{ fd }),
 			outFdList,
 			std::string(base::Platform::XDP::kService));
 
