@@ -830,7 +830,9 @@ bool Supported() {
 bool Enforced() {
 	// Wayland doesn't support positioning
 	// and custom notifications don't work here
-	return IsWayland() || Window::Notifications::OptionGNotification.value();
+	return IsWayland()
+		|| (Gio::Application::get_default()
+			&& Window::Notifications::OptionGNotification.value());
 }
 
 bool ByDefault() {
