@@ -25,6 +25,10 @@ bool SkipFlashBounceForCustom() {
 	return false;
 }
 
+bool WaitForInputForCustom() {
+	return true;
+}
+
 bool Supported() {
 	return false;
 }
