@@ -24,6 +24,10 @@ inline void WriteCrashDumpDetails() {
 inline void AutostartRequestStateFromSystem(Fn<void(bool)> callback) {
 }
 
+inline bool PreventsQuit(Core::QuitReason reason) {
+	return false;
+}
+
 inline void ActivateThisProcess() {
 }
 
