@@ -767,7 +767,7 @@ TimeId CalculateOnlineTill(not_null<PeerData*> peer) {
 		return;
 	}
 
-	const auto active = Core::App().primaryWindow();
+	const auto active = Core::App().activePrimaryWindow();
 	const auto controller = active ? active->sessionController() : nullptr;
 	const auto openFolder = [=] {
 		const auto folder = _session->data().folderLoaded(Data::Folder::kId);
