@@ -7,20 +7,12 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 */
 #pragma once
 
-namespace base::options {
-
-template <typename Type>
-class option;
-
-using toggle = option<bool>;
-
-} // namespace base::options
+namespace Core {
+enum class QuitReason;
+} // namespace Core
 
 namespace Platform {
 
-extern const char kOptionGApplication[];
-extern base::options::toggle OptionGApplication;
-
 void start();
 void finish();
 
@@ -54,7 +46,8 @@ bool TrayIconSupported();
 bool SkipTaskbarSupported();
 void WriteCrashDumpDetails();
 void NewVersionLaunched(int oldVersion);
-void InstallLauncher(bool force = false);
+
+[[nodiscard]] bool PreventsQuit(Core::QuitReason reason);
 
 [[nodiscard]] std::optional<bool> IsDarkMode();
 [[nodiscard]] inline bool IsDarkModeSupported() {
