@@ -41,7 +41,6 @@ public:
 
 protected:
 	void initHook() override;
-	int32 screenNameChecksum(const QString &name) const override;
 	void unreadCounterChangedHook() override;
 
 	void workmodeUpdated(Core::Settings::WorkMode mode) override;
@@ -100,4 +99,6 @@ private:
 
 };
 
+[[nodiscard]] int32 ScreenNameChecksum(const QString &name);
+
 } // namespace Platform
