@@ -18,6 +18,8 @@ public:
 		not_null<Window::SessionController*> controller);
 	~Folders();
 
+	void showFinished() override;
+
 	[[nodiscard]] rpl::producer<QString> title() override;
 
 private:
@@ -25,6 +27,8 @@ private:
 
 	Fn<void()> _save;
 
+	rpl::event_stream<> _showFinished;
+
 };
 
 } // namespace Settings
