@@ -11,12 +11,14 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 
 namespace Settings {
 
-class Notifications : public Section {
+class Notifications : public Section<Notifications> {
 public:
 	Notifications(
 		QWidget *parent,
 		not_null<Window::SessionController*> controller);
 
+	[[nodiscard]] rpl::producer<QString> title() override;
+
 private:
 	void setupContent(not_null<Window::SessionController*> controller);
 
