@@ -34,12 +34,14 @@ void AddPrivacyButton(
 	Api::UserPrivacy::Key key,
 	Fn<std::unique_ptr<EditPrivacyController>()> controllerFactory);
 
-class PrivacySecurity : public Section {
+class PrivacySecurity : public Section<PrivacySecurity> {
 public:
 	PrivacySecurity(
 		QWidget *parent,
 		not_null<Window::SessionController*> controller);
 
+	[[nodiscard]] rpl::producer<QString> title() override;
+
 	rpl::producer<Type> sectionShowOther() override;
 
 private:
