@@ -24,6 +24,10 @@ constexpr auto kFileSizeLimit = 2'000 * int64(1024 * 1024);
 // Load files up to 4'000 MB.
 constexpr auto kFileSizePremiumLimit = 4'000 * int64(1024 * 1024);
 
+extern const char kOptionSendLargePhotos[];
+
+[[nodiscard]] int PhotoSideLimit();
+
 enum class SendMediaType {
 	Photo,
 	Audio,
@@ -224,6 +228,7 @@ struct FileLoadResult {
 		uint64 id,
 		const FileLoadTo &to,
 		const TextWithTags &caption,
+		bool spoiler,
 		std::shared_ptr<SendingAlbum> album);
 
 	TaskId taskId;
@@ -256,6 +261,7 @@ struct FileLoadResult {
 
 	PreparedPhotoThumbs photoThumbs;
 	TextWithTags caption;
+	bool spoiler = false;
 
 	std::vector<MTPInputDocument> attachedStickers;
 
@@ -285,6 +291,7 @@ public:
 		SendMediaType type,
 		const FileLoadTo &to,
 		const TextWithTags &caption,
+		bool spoiler,
 		std::shared_ptr<SendingAlbum> album = nullptr);
 	FileLoadTask(
 		not_null<Main::Session*> session,
@@ -343,6 +350,7 @@ private:
 	VoiceWaveform _waveform;
 	SendMediaType _type;
 	TextWithTags _caption;
+	bool _spoiler = false;
 
 	std::shared_ptr<FileLoadResult> _result;
 
