@@ -135,6 +135,10 @@ public:
 	void writeRecentMasks();
 	void readInstalledMasks();
 	void readRecentMasks();
+	void writeInstalledCustomEmoji();
+	void writeFeaturedCustomEmoji();
+	void readInstalledCustomEmoji();
+	void readFeaturedCustomEmoji();
 
 	void writeRecentHashtagsAndBots();
 	void readRecentHashtagsAndBots();
@@ -284,6 +288,9 @@ private:
 	FileKey _exportSettingsKey = 0;
 	FileKey _installedMasksKey = 0;
 	FileKey _recentMasksKey = 0;
+	FileKey _installedCustomEmojiKey = 0;
+	FileKey _featuredCustomEmojiKey = 0;
+	FileKey _archivedCustomEmojiKey = 0;
 
 	qint64 _cacheTotalSizeLimit = 0;
 	qint64 _cacheBigFileTotalSizeLimit = 0;
