@@ -34,8 +34,8 @@ struct Delta {
 };
 
 bool IsTemplatesFile(const QString &file) {
-	return file.startsWith(qstr("tl_"), Qt::CaseInsensitive)
-		&& file.endsWith(qstr(".txt"), Qt::CaseInsensitive);
+	return file.startsWith(u"tl_"_q, Qt::CaseInsensitive)
+		&& file.endsWith(u".txt"_q, Qt::CaseInsensitive);
 }
 
 QString NormalizeQuestion(const QString &question) {
@@ -78,7 +78,7 @@ void ReadByLine(
 	for (const auto &utf : blob.split('\n')) {
 		const auto line = QString::fromUtf8(utf).trimmed();
 		const auto match = QRegularExpression(
-			qsl("^\\{([A-Z_]+)\\}$")
+			u"^\\{([A-Z_]+)\\}$"_q
 		).match(line);
 		if (match.hasMatch()) {
 			const auto token = match.captured(1);
@@ -86,13 +86,13 @@ void ReadByLine(
 				hadKeys = hadValue = false;
 			}
 			const auto newState = [&] {
-				if (token == qstr("VALUE")) {
+				if (token == u"VALUE"_q) {
 					return hadValue ? State::None : State::Value;
-				} else if (token == qstr("KEYS")) {
+				} else if (token == u"KEYS"_q) {
 					return hadKeys ? State::None : State::Keys;
-				} else if (token == qstr("QUESTION")) {
+				} else if (token == u"QUESTION"_q) {
 					return State::Question;
-				} else if (token == qstr("URL")) {
+				} else if (token == u"URL"_q) {
 					return State::Url;
 				} else {
 					return State::None;
@@ -180,7 +180,7 @@ FileResult ReadFile(const QString &path) {
 	if (!f.open(QIODevice::ReadOnly)) {
 		auto result = FileResult();
 		result.errors.push_back(
-			qsl("Couldn't open '%1' for reading!").arg(path));
+			u"Couldn't open '%1' for reading!"_q.arg(path));
 		return result;
 	}
 
@@ -374,28 +374,28 @@ Delta ComputeDelta(const TemplatesFile &was, const TemplatesFile &now) {
 }
 
 QString FormatUpdateNotification(const QString &path, const Delta &delta) {
-	auto result = qsl("Template file '%1' updated!\n\n").arg(path);
+	auto result = u"Template file '%1' updated!\n\n"_q.arg(path);
 	if (!delta.added.empty()) {
-		result += qstr("-------- Added --------\n\n");
+		result += u"-------- Added --------\n\n"_q;
 		for (const auto question : delta.added) {
-			result += qsl("Q: %1\nK: %2\nA: %3\n\n").arg(
+			result += u"Q: %1\nK: %2\nA: %3\n\n"_q.arg(
 				question->question,
-				question->originalKeys.join(qsl(", ")),
+				question->originalKeys.join(u", "_q),
 				question->value.trimmed());
 		}
 	}
 	if (!delta.changed.empty()) {
-		result += qstr("-------- Modified --------\n\n");
+		result += u"-------- Modified --------\n\n"_q;
 		for (const auto question : delta.changed) {
-			result += qsl("Q: %1\nA: %2\n\n").arg(
+			result += u"Q: %1\nA: %2\n\n"_q.arg(
 				question->question,
 				question->value.trimmed());
 		}
 	}
 	if (!delta.removed.empty()) {
-		result += qstr("-------- Removed --------\n\n");
+		result += u"-------- Removed --------\n\n"_q;
 		for (const auto question : delta.removed) {
-			result += qsl("Q: %1\n\n").arg(question->question);
+			result += u"Q: %1\n\n"_q.arg(question->question);
 		}
 	}
 	return result;
@@ -408,22 +408,19 @@ QString UpdateFile(
 	const Delta &delta) {
 	auto result = QString();
 	const auto full = cWorkingDir() + "TEMPLATES/" + path;
-	const auto old = full + qstr(".old");
+	const auto old = full + u".old"_q;
 	QFile(old).remove();
 	if (QFile(full).copy(old)) {
-		result += qsl("(old file saved at '%1')"
-		).arg(path + qstr(".old"));
+		result += u"(old file saved at '%1')"_q.arg(path + u".old"_q);
 
 		QFile f(full);
 		if (f.open(QIODevice::WriteOnly)) {
 			WriteWithOwnUrlAndKeys(f, content, url, delta);
 		} else {
-			result += qsl("\n\nError: could not open new file '%1'!"
-			).arg(full);
+			result += u"\n\nError: could not open new file '%1'!"_q.arg(full);
 		}
 	} else {
-		result += qsl("Error: could not save old file '%1'!"
-		).arg(old);
+		result += u"Error: could not save old file '%1'!"_q.arg(old);
 	}
 	return result;
 }
@@ -555,8 +552,8 @@ void Templates::updateRequestFinished(QNetworkReply *reply) {
 	}
 	_updates->requests[path] = nullptr;
 	if (reply->error() != QNetworkReply::NoError) {
-		const auto message = qsl(
-			"Error: template update failed, url '%1', error %2, %3"
+		const auto message = (
+			u"Error: template update failed, url '%1', error %2, %3"_q
 		).arg(reply->url().toDisplayString()
 		).arg(reply->error()
 		).arg(reply->errorString());
