@@ -190,6 +190,10 @@ void ItemSingleMediaPreview::startStreamedPlayer() {
 	_streamed->play(options);
 }
 
+bool ItemSingleMediaPreview::supportsSpoilers() const {
+	return false; // We are not allowed to change existing spoiler setting.
+}
+
 bool ItemSingleMediaPreview::drawBackground() const {
 	return true; // A sticker can't be here.
 }
