@@ -140,6 +140,7 @@ void MessageBar::tweenTo(MessageBarContent &&content) {
 		? RectPart::Bottom
 		: RectPart::None;
 	animation.imageFrom = grabImagePart();
+	animation.spoilerFrom = std::move(_spoiler);
 	animation.bodyOrTextFrom = grabBodyOrTextPart(animation.bodyAnimation);
 	const auto sameLength = SameFirstPartLength(
 		_content.title,
@@ -208,6 +209,12 @@ void MessageBar::updateFromContent(MessageBarContent &&content) {
 		Ui::DialogTextOptions(),
 		_content.context);
 	_image = prepareImage(_content.preview);
+	if (!_content.spoilerRepaint) {
+		_spoiler = nullptr;
+	} else if (!_spoiler) {
+		_spoiler = std::make_unique<SpoilerAnimation>(
+			_content.spoilerRepaint);
+	}
 }
 
 QRect MessageBar::imageRect() const {
@@ -258,10 +265,21 @@ auto MessageBar::makeGrabGuard() {
 	auto imageShown = _animation
 		? std::move(_animation->imageShown)
 		: Ui::Animations::Simple();
-	return gsl::finally([&, shown = std::move(imageShown)]() mutable {
+	auto spoiler = std::move(_spoiler);
+	auto fromSpoiler = _animation
+		? std::move(_animation->spoilerFrom)
+		: nullptr;
+	return gsl::finally([
+		&,
+		shown = std::move(imageShown),
+		spoiler = std::move(spoiler),
+		fromSpoiler = std::move(fromSpoiler)
+	]() mutable {
 		if (_animation) {
 			_animation->imageShown = std::move(shown);
+			_animation->spoilerFrom = std::move(fromSpoiler);
 		}
+		_spoiler = std::move(spoiler);
 	});
 }
 
@@ -358,12 +376,20 @@ void MessageBar::paint(Painter &p) {
 		: (_animation->movingTo == RectPart::Top)
 		? (shiftTo - shiftFull)
 		: (shiftTo + shiftFull);
+	const auto now = crl::now();
+	const auto paused = p.inactive();
 
 	paintLeftBar(p);
 
 	if (!_animation) {
 		if (!_image.isNull()) {
-			p.drawPixmap(image, _image);
+			paintImageWithSpoiler(
+				p,
+				image,
+				_image,
+				_spoiler.get(),
+				now,
+				paused);
 		}
 	} else if (!_animation->imageTo.isNull()
 		|| (!_animation->imageFrom.isNull()
@@ -381,14 +407,30 @@ void MessageBar::paint(Painter &p) {
 		}();
 		if (_animation->bodyMoved.animating()) {
 			p.setOpacity(1. - progress);
-			p.drawPixmap(
+			paintImageWithSpoiler(
+				p,
 				rect.translated(0, shiftFrom),
-				_animation->imageFrom);
+				_animation->imageFrom,
+				_animation->spoilerFrom.get(),
+				now,
+				paused);
 			p.setOpacity(progress);
-			p.drawPixmap(rect.translated(0, shiftTo), _animation->imageTo);
+			paintImageWithSpoiler(
+				p,
+				rect.translated(0, shiftTo),
+				_animation->imageTo,
+				_spoiler.get(),
+				now,
+				paused);
 			p.setOpacity(1.);
 		} else {
-			p.drawPixmap(rect, _image);
+			paintImageWithSpoiler(
+				p,
+				rect,
+				_image,
+				_spoiler.get(),
+				now,
+				paused);
 		}
 	}
 	if (!_animation || _animation->bodyAnimation == BodyAnimation::None) {
@@ -409,8 +451,8 @@ void MessageBar::paint(Painter &p) {
 				.availableWidth = body.width(),
 				.palette = &_st.textPalette,
 				.spoiler = Ui::Text::DefaultSpoilerCache(),
-				.now = crl::now(),
-				.paused = p.inactive(),
+				.now = now,
+				.paused = paused,
 				.elisionLines = 1,
 			});
 		}
@@ -510,6 +552,21 @@ void MessageBar::ensureGradientsCreated(int size) {
 	_topBarGradient = Images::PixmapFast(std::move(top));
 }
 
+void MessageBar::paintImageWithSpoiler(
+		QPainter &p,
+		QRect rect,
+		const QPixmap &image,
+		SpoilerAnimation *spoiler,
+		crl::time now,
+		bool paused) const {
+	p.drawPixmap(rect, image);
+	if (spoiler) {
+		const auto frame = DefaultImageSpoiler().frame(
+			spoiler->index(now, paused));
+		FillSpoilerRect(p, rect, frame);
+	}
+}
+
 void MessageBar::paintLeftBar(Painter &p) {
 	const auto state = countBarState();
 	const auto gradientSize = int(std::ceil(state.size * 2.5));
