@@ -7,7 +7,6 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 */
 #include "ui/empty_userpic.h"
 
-#include "data/data_peer.h"
 #include "ui/emoji_config.h"
 #include "ui/effects/animation_value.h"
 #include "ui/painter.h"
@@ -194,24 +193,23 @@ void PaintInaccessibleAccountInner(
 	}
 }
 
-template <typename Callback>
-[[nodiscard]] QPixmap Generate(int size, Callback callback) {
+[[nodiscard]] QImage Generate(int size, Fn<void(QPainter&)> callback) {
 	auto result = QImage(
-		QSize(size, size) * cIntRetinaFactor(),
+		QSize(size, size) * style::DevicePixelRatio(),
 		QImage::Format_ARGB32_Premultiplied);
-	result.setDevicePixelRatio(cRetinaFactor());
+	result.setDevicePixelRatio(style::DevicePixelRatio());
 	result.fill(Qt::transparent);
 	{
 		Painter p(&result);
 		callback(p);
 	}
-	return Ui::PixmapFromImage(std::move(result));
+	return result;
 }
 
 } // namespace
 
-EmptyUserpic::EmptyUserpic(const style::color &color, const QString &name)
-: _color(color) {
+EmptyUserpic::EmptyUserpic(const BgColors &colors, const QString &name)
+: _colors(colors) {
 	fillString(name);
 }
 
@@ -223,29 +221,60 @@ QString EmptyUserpic::InaccessibleName() {
 	return QChar(0) + u"inaccessible"_q;
 }
 
-template <typename Callback>
+int EmptyUserpic::ColorIndex(uint64 id) {
+	const auto index = id % 7;
+	const int map[] = { 0, 7, 4, 1, 6, 3, 5 };
+	return map[index];
+}
+
+EmptyUserpic::BgColors EmptyUserpic::UserpicColor(int id) {
+	const EmptyUserpic::BgColors colors[] = {
+		{ st::historyPeer1UserpicBg, st::historyPeer1UserpicBg2 },
+		{ st::historyPeer2UserpicBg, st::historyPeer2UserpicBg2 },
+		{ st::historyPeer3UserpicBg, st::historyPeer3UserpicBg2 },
+		{ st::historyPeer4UserpicBg, st::historyPeer4UserpicBg2 },
+		{ st::historyPeer5UserpicBg, st::historyPeer5UserpicBg2 },
+		{ st::historyPeer6UserpicBg, st::historyPeer6UserpicBg2 },
+		{ st::historyPeer7UserpicBg, st::historyPeer7UserpicBg2 },
+		{ st::historyPeer8UserpicBg, st::historyPeer8UserpicBg2 },
+	};
+	return colors[id];
+}
+
 void EmptyUserpic::paint(
 		QPainter &p,
 		int x,
 		int y,
 		int outerWidth,
 		int size,
-		Callback paintBackground) const {
-	x = rtl() ? (outerWidth - x - size) : x;
+		Fn<void()> paintBackground) const {
+	x = style::RightToLeft() ? (outerWidth - x - size) : x;
 
 	const auto fontsize = (size * 13) / 33;
 	auto font = st::historyPeerUserpicFont->f;
 	font.setPixelSize(fontsize);
 
 	PainterHighQualityEnabler hq(p);
-	p.setBrush(_color);
+	{
+		auto gradient = QLinearGradient(x, y, x, y + size);
+		gradient.setStops({
+			{ 0., _colors.color1->c },
+			{ 1., _colors.color2->c }
+		});
+		p.setBrush(gradient);
+	}
 	p.setPen(Qt::NoPen);
 	paintBackground();
 
 	if (IsExternal(_string)) {
 		PaintExternalMessagesInner(p, x, y, size, st::historyPeerUserpicFg);
 	} else if (IsInaccessible(_string)) {
-		PaintInaccessibleAccountInner(p, x, y, size, st::historyPeerUserpicFg);
+		PaintInaccessibleAccountInner(
+			p,
+			x,
+			y,
+			size,
+			st::historyPeerUserpicFg);
 	} else {
 		p.setFont(font);
 		p.setBrush(Qt::NoBrush);
@@ -257,7 +286,7 @@ void EmptyUserpic::paint(
 	}
 }
 
-void EmptyUserpic::paint(
+void EmptyUserpic::paintCircle(
 		QPainter &p,
 		int x,
 		int y,
@@ -275,15 +304,17 @@ void EmptyUserpic::paintRounded(
 		int outerWidth,
 		int size,
 		int radius) const {
-	if (!radius) {
-		radius = st::roundRadiusSmall;
-	}
 	paint(p, x, y, outerWidth, size, [&] {
 		p.drawRoundedRect(x, y, size, size, radius, radius);
 	});
 }
 
-void EmptyUserpic::paintSquare(QPainter &p, int x, int y, int outerWidth, int size) const {
+void EmptyUserpic::paintSquare(
+		QPainter &p,
+		int x,
+		int y,
+		int outerWidth,
+		int size) const {
 	paint(p, x, y, outerWidth, size, [&] {
 		p.fillRect(x, y, size, size, p.brush());
 	});
@@ -295,20 +326,13 @@ void EmptyUserpic::PaintSavedMessages(
 		int y,
 		int outerWidth,
 		int size) {
-	const auto &bg = st::historyPeerSavedMessagesBg;
+	auto bg = QLinearGradient(x, y, x, y + size);
+	bg.setStops({
+		{ 0., st::historyPeerSavedMessagesBg->c },
+		{ 1., st::historyPeerSavedMessagesBg2->c }
+	});
 	const auto &fg = st::historyPeerUserpicFg;
-	PaintSavedMessages(p, x, y, outerWidth, size, bg, fg);
-}
-
-void EmptyUserpic::PaintSavedMessagesRounded(
-		QPainter &p,
-		int x,
-		int y,
-		int outerWidth,
-		int size) {
-	const auto &bg = st::historyPeerSavedMessagesBg;
-	const auto &fg = st::historyPeerUserpicFg;
-	PaintSavedMessagesRounded(p, x, y, outerWidth, size, bg, fg);
+	PaintSavedMessages(p, x, y, outerWidth, size, QBrush(bg), fg);
 }
 
 void EmptyUserpic::PaintSavedMessages(
@@ -317,68 +341,37 @@ void EmptyUserpic::PaintSavedMessages(
 		int y,
 		int outerWidth,
 		int size,
-		const style::color &bg,
+		QBrush bg,
 		const style::color &fg) {
-	x = rtl() ? (outerWidth - x - size) : x;
+	x = style::RightToLeft() ? (outerWidth - x - size) : x;
 
 	PainterHighQualityEnabler hq(p);
-	p.setBrush(bg);
+	p.setBrush(std::move(bg));
 	p.setPen(Qt::NoPen);
 	p.drawEllipse(x, y, size, size);
 
 	PaintSavedMessagesInner(p, x, y, size, fg);
 }
 
-void EmptyUserpic::PaintSavedMessagesRounded(
-		QPainter &p,
-		int x,
-		int y,
-		int outerWidth,
-		int size,
-		const style::color &bg,
-		const style::color &fg) {
-	x = rtl() ? (outerWidth - x - size) : x;
-
-	PainterHighQualityEnabler hq(p);
-	p.setBrush(bg);
-	p.setPen(Qt::NoPen);
-	p.drawRoundedRect(x, y, size, size, st::roundRadiusSmall, st::roundRadiusSmall);
-
-	PaintSavedMessagesInner(p, x, y, size, fg);
-}
-
-QPixmap EmptyUserpic::GenerateSavedMessages(int size) {
+QImage EmptyUserpic::GenerateSavedMessages(int size) {
 	return Generate(size, [&](QPainter &p) {
 		PaintSavedMessages(p, 0, 0, size, size);
 	});
 }
 
-QPixmap EmptyUserpic::GenerateSavedMessagesRounded(int size) {
-	return Generate(size, [&](QPainter &p) {
-		PaintSavedMessagesRounded(p, 0, 0, size, size);
-	});
-}
-
 void EmptyUserpic::PaintRepliesMessages(
 		QPainter &p,
 		int x,
 		int y,
 		int outerWidth,
 		int size) {
-	const auto &bg = st::historyPeerSavedMessagesBg;
+	auto bg = QLinearGradient(x, y, x, y + size);
+	bg.setStops({
+		{ 0., st::historyPeerSavedMessagesBg->c },
+		{ 1., st::historyPeerSavedMessagesBg2->c }
+	});
 	const auto &fg = st::historyPeerUserpicFg;
-	PaintRepliesMessages(p, x, y, outerWidth, size, bg, fg);
-}
-
-void EmptyUserpic::PaintRepliesMessagesRounded(
-		QPainter &p,
-		int x,
-		int y,
-		int outerWidth,
-		int size) {
-	const auto &bg = st::historyPeerSavedMessagesBg;
-	const auto &fg = st::historyPeerUserpicFg;
-	PaintRepliesMessagesRounded(p, x, y, outerWidth, size, bg, fg);
+	PaintRepliesMessages(p, x, y, outerWidth, size, QBrush(bg), fg);
 }
 
 void EmptyUserpic::PaintRepliesMessages(
@@ -387,9 +380,9 @@ void EmptyUserpic::PaintRepliesMessages(
 		int y,
 		int outerWidth,
 		int size,
-		const style::color &bg,
+		QBrush bg,
 		const style::color &fg) {
-	x = rtl() ? (outerWidth - x - size) : x;
+	x = style::RightToLeft() ? (outerWidth - x - size) : x;
 
 	PainterHighQualityEnabler hq(p);
 	p.setBrush(bg);
@@ -399,51 +392,32 @@ void EmptyUserpic::PaintRepliesMessages(
 	PaintRepliesMessagesInner(p, x, y, size, fg);
 }
 
-void EmptyUserpic::PaintRepliesMessagesRounded(
-		QPainter &p,
-		int x,
-		int y,
-		int outerWidth,
-		int size,
-		const style::color &bg,
-		const style::color &fg) {
-	x = rtl() ? (outerWidth - x - size) : x;
-
-	PainterHighQualityEnabler hq(p);
-	p.setBrush(bg);
-	p.setPen(Qt::NoPen);
-	p.drawRoundedRect(x, y, size, size, st::roundRadiusSmall, st::roundRadiusSmall);
-
-	PaintRepliesMessagesInner(p, x, y, size, fg);
-}
-
-QPixmap EmptyUserpic::GenerateRepliesMessages(int size) {
+QImage EmptyUserpic::GenerateRepliesMessages(int size) {
 	return Generate(size, [&](QPainter &p) {
 		PaintRepliesMessages(p, 0, 0, size, size);
 	});
 }
 
-QPixmap EmptyUserpic::GenerateRepliesMessagesRounded(int size) {
-	return Generate(size, [&](QPainter &p) {
-		PaintRepliesMessagesRounded(p, 0, 0, size, size);
-	});
-}
-
-InMemoryKey EmptyUserpic::uniqueKey() const {
+std::pair<uint64, uint64> EmptyUserpic::uniqueKey() const {
 	const auto first = (uint64(0xFFFFFFFFU) << 32)
-		| anim::getPremultiplied(_color->c);
+		| anim::getPremultiplied(_colors.color1->c);
 	auto second = uint64(0);
-	memcpy(&second, _string.constData(), qMin(sizeof(second), _string.size() * sizeof(QChar)));
-	return InMemoryKey(first, second);
+	memcpy(
+		&second,
+		_string.constData(),
+		std::min(sizeof(second), size_t(_string.size()) * sizeof(QChar)));
+	return { first, second };
 }
 
 QPixmap EmptyUserpic::generate(int size) {
-	auto result = QImage(QSize(size, size) * cIntRetinaFactor(), QImage::Format_ARGB32_Premultiplied);
-	result.setDevicePixelRatio(cRetinaFactor());
+	auto result = QImage(
+		QSize(size, size) * style::DevicePixelRatio(),
+		QImage::Format_ARGB32_Premultiplied);
+	result.setDevicePixelRatio(style::DevicePixelRatio());
 	result.fill(Qt::transparent);
 	{
 		auto p = QPainter(&result);
-		paint(p, 0, 0, size, size);
+		paintCircle(p, 0, 0, size, size);
 	}
 	return Ui::PixmapFromImage(std::move(result));
 }
