@@ -11,7 +11,6 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 
 namespace Ui::Text {
 class CustomEmoji;
-struct CustomEmojiColored;
 } // namespace Ui::Text
 
 namespace Ui {
@@ -43,7 +42,6 @@ public:
 		const style::icon *premium = nullptr;
 		const style::color *scam = nullptr;
 		const style::color *premiumFg = nullptr;
-		QColor preview;
 		Fn<void()> customEmojiRepaint;
 		crl::time now = 0;
 		bool paused = false;
@@ -60,7 +58,6 @@ private:
 	struct EmojiStatus {
 		DocumentId id = 0;
 		std::unique_ptr<Ui::Text::CustomEmoji> emoji;
-		std::unique_ptr<Ui::Text::CustomEmojiColored> colored;
 		int skip = 0;
 	};
 	std::unique_ptr<EmojiStatus> _emojiStatus;
