@@ -83,7 +83,7 @@ public:
 	void updateIsActive();
 
 	[[nodiscard]] bool isActive() const {
-		return _isActive;
+		return !isHidden() && _isActive;
 	}
 	[[nodiscard]] virtual bool isActiveForTrayMenu() {
 		updateIsActive();
@@ -134,9 +134,10 @@ public:
 		updateGlobalMenuHook();
 	}
 
-	[[nodiscard]] virtual bool preventsQuit(Core::QuitReason reason) {
-		return false;
-	}
+	[[nodiscard]] QRect countInitialGeometry(
+		Core::WindowPosition position,
+		Core::WindowPosition initial,
+		QSize minSize) const;
 
 protected:
 	void leaveEventHook(QEvent *e) override;
@@ -178,9 +179,6 @@ protected:
 		return false;
 	}
 
-	// This one is overriden in Windows for historical reasons.
-	virtual int32 screenNameChecksum(const QString &name) const;
-
 	void setPositionInited();
 
 	virtual QRect computeDesktopRect() const;
@@ -222,4 +220,15 @@ private:
 
 };
 
+[[nodiscard]] int32 DefaultScreenNameChecksum(const QString &name);
+
+[[nodiscard]] Core::WindowPosition PositionWithScreen(
+	Core::WindowPosition position,
+	const QScreen *chosen,
+	QSize minimal);
+[[nodiscard]] Core::WindowPosition PositionWithScreen(
+	Core::WindowPosition position,
+	not_null<const QWidget*> widget,
+	QSize minimal);
+
 } // namespace Window
