@@ -41,6 +41,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "ui/widgets/menu/menu_add_action_callback_factory.h"
 #include "ui/layers/generic_box.h"
 #include "ui/toasts/common_toasts.h"
+#include "ui/delayed_activation.h"
 #include "main/main_session.h"
 #include "main/main_session_settings.h"
 #include "menu/menu_mute.h"
@@ -81,6 +82,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "core/application.h"
 #include "export/export_manager.h"
 #include "boxes/peers/edit_peer_info_box.h"
+#include "styles/style_chat.h"
 #include "styles/style_layers.h"
 #include "styles/style_boxes.h"
 #include "styles/style_window.h" // st::windowMinWidth
@@ -254,6 +256,7 @@ private:
 	void addToggleMuteSubmenu(bool addSeparator);
 	void addSupportInfo();
 	void addInfo();
+	void addNewWindow();
 	void addToggleFolder();
 	void addToggleUnreadMark();
 	void addToggleArchive();
@@ -270,6 +273,7 @@ private:
 	void addViewDiscussion();
 	void addToggleTopicClosed();
 	void addExportChat();
+	void addTranslate();
 	void addReport();
 	void addNewContact();
 	void addShareContact();
@@ -596,6 +600,25 @@ void Filler::addToggleUnreadMark() {
 	}, (unread ? &st::menuIconMarkRead : &st::menuIconMarkUnread));
 }
 
+void Filler::addNewWindow() {
+	const auto history = _request.key.history();
+	if (!_peer
+		|| _topic
+		|| _peer->isForum()
+		|| (history
+			&& history->useTopPromotion()
+			&& !history->topPromotionType().isEmpty())) {
+		return;
+	}
+	const auto peer = _peer;
+	const auto controller = _controller;
+	_addAction(tr::lng_context_new_window(tr::now), [=] {
+		Ui::PreventDelayedActivation();
+		controller->showInNewWindow(peer);
+	}, &st::menuIconNewWindow);
+	AddSeparatorAndShiftUp(_addAction);
+}
+
 void Filler::addToggleArchive() {
 	if (!_peer || _topic) {
 		return;
@@ -776,6 +799,23 @@ void Filler::addExportChat() {
 		&st::menuIconExport);
 }
 
+void Filler::addTranslate() {
+	if (_peer->translationFlag() != PeerData::TranslationFlag::Disabled
+		|| !_peer->session().premium()
+		|| !Core::App().settings().translateChatEnabled()) {
+		return;
+	}
+	const auto history = _peer->owner().historyLoaded(_peer);
+	if (!history
+		|| !history->translateOfferedFrom()
+		|| history->translatedTo()) {
+		return;
+	}
+	_addAction(tr::lng_context_translate(tr::now), [=] {
+		history->peer->saveTranslationDisabled(false);
+	}, &st::menuIconTranslate);
+}
+
 void Filler::addReport() {
 	const auto chat = _peer->asChat();
 	const auto channel = _peer->asChannel();
@@ -951,7 +991,10 @@ void Filler::addManageChat() {
 }
 
 void Filler::addCreatePoll() {
-	if (!(_topic ? _topic->canSendPolls() : _peer->canSendPolls())) {
+	const auto can = _topic
+		? Data::CanSend(_topic, ChatRestriction::SendPolls)
+		: _peer->canCreatePolls();
+	if (!can) {
 		return;
 	}
 	const auto peer = _peer;
@@ -1140,6 +1183,7 @@ void Filler::addVideoChat() {
 }
 
 void Filler::fillContextMenuActions() {
+	addNewWindow();
 	addHidePromotion();
 	addToggleArchive();
 	addTogglePin();
@@ -1170,6 +1214,7 @@ void Filler::fillHistoryActions() {
 	addThemeEdit();
 	addViewDiscussion();
 	addExportChat();
+	addTranslate();
 	addReport();
 	addClearHistory();
 	addDeleteChat();
@@ -1329,7 +1374,7 @@ void PeerMenuShareContactBox(
 	const auto weak = std::make_shared<QPointer<Ui::BoxContent>>();
 	auto callback = [=](not_null<Data::Thread*> thread) {
 		const auto peer = thread->peer();
-		if (!thread->canWrite()) {
+		if (!Data::CanSend(thread, ChatRestriction::SendOther)) {
 			navigation->parentController()->show(
 				Ui::MakeInformBox(tr::lng_forward_share_cant()),
 				Ui::LayerOption::KeepOther);
@@ -1946,10 +1991,9 @@ QPointer<Ui::BoxContent> ShowShareGameBox(
 			Ui::LayerOption::KeepOther);
 	};
 	auto filter = [](not_null<Data::Thread*> thread) {
-		const auto peer = thread->peer();
-		return (thread->canWrite() || thread->asForum())
-			&& !peer->amRestricted(ChatRestriction::SendGames)
-			&& !peer->isSelf();
+		return !thread->peer()->isSelf()
+			&& (Data::CanSend(thread, ChatRestriction::SendGames)
+				|| thread->asForum());
 	};
 	auto initBox = [](not_null<PeerListBox*> box) {
 		box->addButton(tr::lng_cancel(), [box] {
@@ -2391,4 +2435,17 @@ void MarkAsReadThread(not_null<Data::Thread*> thread) {
 	}
 }
 
+void AddSeparatorAndShiftUp(const PeerMenuCallback &addAction) {
+	addAction({ .isSeparator = true });
+
+	const auto &st = st::popupMenuExpandedSeparator.menu;
+	const auto shift = st::popupMenuExpandedSeparator.scrollPadding.top()
+		+ st.itemPadding.top()
+		+ st.itemStyle.font->height
+		+ st.itemPadding.bottom()
+		+ st.separator.padding.top()
+		+ st.separator.width / 2;
+	addAction({ .addTopShift = -shift });
+}
+
 } // namespace Window
