@@ -337,9 +337,10 @@ public:
 		object_ptr<Ui::BoxContent> content,
 		Ui::LayerOptions options = Ui::LayerOption::KeepOther,
 		anim::type animated = anim::type::normal);
-
 	void hideLayer(anim::type animated = anim::type::normal);
 
+	void showToast(TextWithEntities &&text);
+
 	[[nodiscard]] auto sendingAnimation() const
 	-> Ui::MessageSendingAnimationController &;
 	[[nodiscard]] auto tabbedSelector() const
@@ -476,6 +477,10 @@ public:
 		Fn<void(MessageIdsList)> done);
 	void clearChooseReportMessages();
 
+	void showInNewWindow(
+		not_null<PeerData*> peer,
+		MsgId msgId = ShowAtUnreadMsgId);
+
 	void toggleChooseChatTheme(not_null<PeerData*> peer);
 
 	[[nodiscard]] bool dialogsListFocused() const {
@@ -552,6 +557,10 @@ public:
 		return *_cachedReactionIconFactory;
 	}
 
+	[[nodiscard]] QString authedName() const {
+		return _authedName;
+	}
+
 	void setPremiumRef(const QString &ref);
 	[[nodiscard]] QString premiumRef() const;
 
@@ -604,6 +613,8 @@ private:
 	const std::unique_ptr<ChatHelpers::EmojiInteractions> _emojiInteractions;
 	const bool _isPrimary = false;
 
+	QString _authedName;
+
 	using SendingAnimation = Ui::MessageSendingAnimationController;
 	const std::unique_ptr<SendingAnimation> _sendingAnimation;
 
