@@ -8,9 +8,6 @@ class Thread;
 template <class T>
 class scoped_refptr;
 }
-namespace webrtc {
-class SharedModuleThread;
-}
 
 namespace tgcalls {
 
@@ -20,7 +17,6 @@ public:
   virtual rtc::Thread *getNetworkThread() = 0;
   virtual rtc::Thread *getMediaThread() = 0;
   virtual rtc::Thread *getWorkerThread() = 0;
-  virtual rtc::scoped_refptr<webrtc::SharedModuleThread> getSharedModuleThread() = 0;
 
   // it is not possible to decrease pool size
   static void setPoolSize(size_t size);
@@ -31,7 +27,6 @@ namespace StaticThreads {
 rtc::Thread *getNetworkThread();
 rtc::Thread *getMediaThread();
 rtc::Thread *getWorkerThread();
-rtc::scoped_refptr<webrtc::SharedModuleThread> getSharedMoudleThread();
 std::shared_ptr<Threads> &getThreads();
 }
 
