@@ -2,7 +2,6 @@
 #define TGCALLS_THREAD_LOCAL_OBJECT_H
 
 #include "rtc_base/thread.h"
-#include "rtc_base/location.h"
 
 #include <functional>
 #include <memory>
@@ -31,7 +30,7 @@ public:
 	}
 
 	template <typename FunctorT>
-	void perform(const rtc::Location& posted_from, FunctorT &&functor) {
+	void perform(FunctorT &&functor) {
 		_thread->PostTask([valueHolder = _valueHolder.get(), f = std::forward<FunctorT>(functor)]() mutable {
 			assert(valueHolder->_value != nullptr);
 			f(valueHolder->_value.get());
