@@ -10,7 +10,6 @@
 
 #import "tgcalls_voice_processing_audio_unit.h"
 
-#include "absl/base/macros.h"
 #include "rtc_base/checks.h"
 #include "system_wrappers/include/metrics.h"
 
@@ -304,7 +303,9 @@ bool VoiceProcessingAudioUnit::Initialize(Float64 sample_rate) {
     // converted into a postive value to match the UMA APIs.
     RTC_HISTOGRAM_COUNTS_SPARSE_100000(
         "WebRTC.Audio.GetAGCStateErrorCode1", (-1) * result);
-  } else if (agc_is_enabled) {
+  }
+      
+  if (agc_is_enabled) {
     // Remember that the AGC was enabled by default. Will be used in UMA.
     agc_was_enabled_by_default = 1;
   } else {
@@ -331,7 +332,7 @@ bool VoiceProcessingAudioUnit::Initialize(Float64 sample_rate) {
           "WebRTC.Audio.GetAGCStateErrorCode2", (-1) * result);
     }
   }
-      
+
   // Track if the built-in AGC was enabled by default (as it should) or not.
   RTC_HISTOGRAM_BOOLEAN("WebRTC.Audio.BuiltInAGCWasEnabledByDefault",
                         agc_was_enabled_by_default);
@@ -482,13 +483,11 @@ void VoiceProcessingAudioUnit::DisposeAudioUnit() {
     switch (state_) {
       case kStarted:
         Stop();
-        // Fall through.
-        ABSL_FALLTHROUGH_INTENDED;
+        [[fallthrough]];
       case kInitialized:
         Uninitialize();
         break;
       case kUninitialized:
-        ABSL_FALLTHROUGH_INTENDED;
       case kInitRequired:
         break;
     }
