@@ -10,44 +10,25 @@
 
 namespace Platform {
 
+inline OutdateReason WhySystemBecomesOutdated() {
+	return OutdateReason::IsOld;
+}
+
 inline constexpr bool IsLinux() {
 	return true;
 }
 
-inline constexpr bool IsLinux32Bit() {
-#ifdef Q_PROCESSOR_X86_32
-	return true;
-#else // Q_PROCESSOR_X86_32
-	return false;
-#endif // Q_PROCESSOR_X86_32
-}
-
-inline constexpr bool IsLinux64Bit() {
-#ifdef Q_PROCESSOR_X86_64
-	return true;
-#else // Q_PROCESSOR_X86_64
-	return false;
-#endif // Q_PROCESSOR_X86_64
-}
-
 inline constexpr bool IsWindows() { return false; }
 inline constexpr bool IsWindows32Bit() { return false; }
 inline constexpr bool IsWindows64Bit() { return false; }
 inline constexpr bool IsWindowsStoreBuild() { return false; }
-inline bool IsWindowsXPOrGreater() { return false; }
-inline bool IsWindowsVistaOrGreater() { return false; }
 inline bool IsWindows7OrGreater() { return false; }
 inline bool IsWindows8OrGreater() { return false; }
 inline bool IsWindows8Point1OrGreater() { return false; }
 inline bool IsWindows10OrGreater() { return false; }
+inline bool IsWindows11OrGreater() { return false; }
 inline constexpr bool IsMac() { return false; }
 inline constexpr bool IsMacStoreBuild() { return false; }
-inline bool IsMac10_6OrGreater() { return false; }
-inline bool IsMac10_7OrGreater() { return false; }
-inline bool IsMac10_8OrGreater() { return false; }
-inline bool IsMac10_9OrGreater() { return false; }
-inline bool IsMac10_10OrGreater() { return false; }
-inline bool IsMac10_11OrGreater() { return false; }
 inline bool IsMac10_12OrGreater() { return false; }
 inline bool IsMac10_13OrGreater() { return false; }
 inline bool IsMac10_14OrGreater() { return false; }
