@@ -47,10 +47,6 @@ bool Integration::screenIsLocked() {
 	return false;
 }
 
-QString Integration::timeFormat() {
-	return u"hh:mm"_q;
-}
-
 std::shared_ptr<ClickHandler> Integration::createLinkHandler(
 		const EntityLinkData &data,
 		const std::any &context) {
