@@ -149,13 +149,12 @@ void Widget::paintEvent(QPaintEvent *e) {
 			width());
 	}
 
-	p.setTextPalette(_st->palette);
-
 	const auto lines = _maxTextHeight / _st->style.font->height;
 	p.setPen(st::toastFg);
 	_text.draw(p, {
 		.position = { _st->padding.left(), _textTop },
 		.availableWidth = _textWidth + 1,
+		.palette = &_st->palette,
 		.spoiler = Ui::Text::DefaultSpoilerCache(),
 		.elisionLines = lines,
 	});
