@@ -37,9 +37,11 @@ const auto kEditLinkSequence = QKeySequence("ctrl+k");
 const auto kSpoilerSequence = QKeySequence("ctrl+shift+p");
 
 class PopupMenu;
+class InputField;
 
 void InsertEmojiAtCursor(QTextCursor cursor, EmojiPtr emoji);
 void InsertCustomEmojiAtCursor(
+	not_null<InputField*> field,
 	QTextCursor cursor,
 	const QString &text,
 	const QString &link);
@@ -152,6 +154,10 @@ public:
 		rpl::producer<QString> placeholder = nullptr,
 		const TextWithTags &value = TextWithTags());
 
+	[[nodiscard]] const style::InputField &st() const {
+		return _st;
+	}
+
 	void showError();
 	void showErrorNoFocus();
 	void hideError();
