@@ -440,6 +440,10 @@ void PopupMenu::clearActions() {
 	return _menu->clearActions();
 }
 
+void PopupMenu::setTopShift(int topShift) {
+	_topShift = topShift;
+}
+
 void PopupMenu::setForceWidth(int forceWidth) {
 	_menu->setForceWidth(forceWidth);
 }
@@ -484,7 +488,10 @@ void PopupMenu::paintEvent(QPaintEvent *e) {
 		_showAnimation->paintFrame(p, 0, 0, width(), 1., 1.);
 		_showAnimation.reset();
 		_showStateChanges.fire({});
-		PostponeCall(this, [=] { showChildren(); });
+		PostponeCall(this, [=] {
+			showChildren();
+			_animatePhase = AnimatePhase::Shown;
+		});
 	} else {
 		paintBg(p);
 	}
@@ -545,7 +552,10 @@ void PopupMenu::popupSubmenu(
 		currentSubmenu->hideMenu(true);
 	}
 	if (submenu) {
-		QPoint p(_inner.x() + (style::RightToLeft() ? _padding.right() : (_inner.width() - _padding.left())), _inner.y() + actionTop);
+		const auto padding = _useTransparency
+			? _st.shadow.extend
+			: QMargins(st::lineWidth, 0, st::lineWidth, 0);
+		QPoint p(_inner.x() + (style::RightToLeft() ? padding.right() : (_inner.width() - padding.left())), _inner.y() + actionTop);
 		_activeSubmenu = submenu;
 		if (_activeSubmenu->prepareGeometryFor(geometry().topLeft() + p, this)) {
 			_activeSubmenu->showPrepared(source);
@@ -747,6 +757,7 @@ void PopupMenu::hideFinished() {
 	_hiding = false;
 	_a_show.stop();
 	_cache = QPixmap();
+	_animatePhase = AnimatePhase::Hidden;
 	if (!isHidden()) {
 		hide();
 	}
@@ -787,6 +798,9 @@ void PopupMenu::startOpacityAnimation(bool hiding) {
 	_hiding = false;
 	prepareCache();
 	_hiding = hiding;
+	_animatePhase = hiding
+		? AnimatePhase::StartHide
+		: AnimatePhase::StartShow;
 	hideChildren();
 	_a_opacity.start(
 		[=] { opacityAnimationCallback(); },
@@ -829,6 +843,7 @@ void PopupMenu::startShowAnimation() {
 		}
 		_showAnimation->start();
 	}
+	_animatePhase = AnimatePhase::StartShow;
 	hideChildren();
 	_a_show.start([this] { showAnimationCallback(); }, 0., 1., _st.showDuration);
 	fireCurrentShowState();
@@ -855,6 +870,7 @@ void PopupMenu::opacityAnimationCallback() {
 			hideFinished();
 		} else {
 			showChildren();
+			_animatePhase = AnimatePhase::Shown;
 		}
 	}
 }
@@ -981,13 +997,14 @@ bool PopupMenu::prepareGeometryFor(const QPoint &p, PopupMenu *parent) {
 		std::max(
 			_additionalMenuPadding.left() - _st.shadow.extend.left(),
 			0),
-		_padding.top());
+		_padding.top() - _topShift);
 	auto r = screen ? screen->availableGeometry() : QRect();
+	const auto parentWidth = _parent ? _parent->inner().width() : 0;
 	if (style::RightToLeft()) {
 		const auto badLeft = !r.isNull() && w.x() - width() < r.x() - _extents.left();
 		if (forceRight || (badLeft && !forceLeft)) {
-			if (_parent && (r.isNull() || w.x() + _parent->width() - _extents.left() - _extents.right() + width() - _extents.right() <= r.x() + r.width())) {
-				w.setX(w.x() + _parent->width() - _extents.left() - _extents.right());
+			if (_parent && (r.isNull() || w.x() + parentWidth - _extents.left() - _extents.right() + width() - _extents.right() <= r.x() + r.width())) {
+				w.setX(w.x() + parentWidth - _extents.left() - _extents.right());
 			} else {
 				w.setX(r.x() - _extents.left());
 			}
@@ -997,8 +1014,8 @@ bool PopupMenu::prepareGeometryFor(const QPoint &p, PopupMenu *parent) {
 	} else {
 		const auto badLeft = !r.isNull() && w.x() + width() - _extents.right() > r.x() + r.width();
 		if (forceRight || (badLeft && !forceLeft)) {
-			if (_parent && (r.isNull() || w.x() - _parent->width() + _extents.left() + _extents.right() - width() + _extents.right() >= r.x() - _extents.left())) {
-				w.setX(w.x() + _extents.left() + _extents.right() - _parent->width() - width() + _extents.left() + _extents.right());
+			if (_parent && (r.isNull() || w.x() - parentWidth + _extents.left() + _extents.right() - width() + _extents.right() >= r.x() - _extents.left())) {
+				w.setX(w.x() + _extents.left() + _extents.right() - parentWidth - width() + _extents.left() + _extents.right());
 			} else {
 				w.setX(p.x() - width() + std::max(
 					_additionalMenuPadding.right() - _st.shadow.extend.right(),
